package org.openxma.dsl.reference.base;

import org.openxma.dsl.platform.service.MapperContextHolder;
import java.util.ArrayList;
import java.util.List;
import org.openxma.dsl.platform.assembler.DtoAssembler;
import org.openxma.dsl.platform.assembler.DtoAssemblerFactory;
import org.openxma.dsl.platform.assembler.DtoAssemblerRegistry;
import org.openxma.dsl.platform.converter.Converter;
import org.openxma.dsl.reference.base.dto.BaseEntityView;
import org.openxma.dsl.reference.base.model.BaseEntity;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.Assert;

public class DtoAssemblerFactoryBaseGen implements DtoAssemblerFactory {

	private List<DtoAssembler<?>> dtoAssemblers;

	@Autowired
	private DtoAssemblerRegistry dtoAssemblerRegistry;
	
	@Autowired
	private Converter converter;

	public DtoAssemblerFactoryBaseGen() {
		dtoAssemblers = new ArrayList<DtoAssembler<?>>(1);
		initDtoAssemblers();
	}


	public List<DtoAssembler<?>> getDtoAssemblers() {
		return dtoAssemblers;
	}

	protected DtoAssemblerRegistry getDtoAssemblerRegistry() {
		return dtoAssemblerRegistry;
	}
	
	protected Converter getConverter() {
		return converter;
	}

	private void initDtoAssemblers() {
		dtoAssemblers.add(createDtoAssemblerBaseEntityView());
	}


	private DtoAssembler<BaseEntityView> createDtoAssemblerBaseEntityView() {
		return new DtoAssembler<BaseEntityView>() {
			public BaseEntityView mapFromEntity(Object sourceEntity) {
				Assert.notNull(sourceEntity, "parameter 'sourceEntity' must not be null");
				if (sourceEntity instanceof BaseEntity) {
					BaseEntity baseEntity = (BaseEntity) sourceEntity;
					BaseEntityView result = mapFromBaseEntityToBaseEntityView(baseEntity);
					return result;
				}
				throw new IllegalArgumentException("mapping from object '"+sourceEntity+"' is not supported");
					
			}
			
			public BaseEntityView mapFromEntity(Object sourceEntity, BaseEntityView targetDto) {
				Assert.notNull(sourceEntity, "parameter 'sourceEntity' must not be null");
				Assert.notNull(targetDto, "parameter 'targetDto' must not be null");
				if (sourceEntity instanceof BaseEntity) {
					BaseEntity baseEntity = (BaseEntity) sourceEntity;
					mapFromBaseEntityToBaseEntityView(baseEntity, targetDto);
					return targetDto;
				}
				throw new IllegalArgumentException("mapping from object '"+sourceEntity+"' is not supported");
					
			}
			
			public <T> T mapTo(BaseEntityView sourceDto, Class<T> target) {
				if (BaseEntityView.class.equals(target)) {
					BaseEntityView result = new BaseEntityView();
					mapFromBaseEntityViewToBaseEntityView(sourceDto, result);
					return target.cast(result);
				}
				else if (BaseEntity.class.equals(target)) {
					return target.cast(mapFromBaseEntityViewToBaseEntity(sourceDto));
				}
				else {
					throw new IllegalArgumentException("mapping to class '"+target+"' is not supported");
				}
			}
			
			public void mapTo(BaseEntityView sourceDto, Object targetObject) {
				if (targetObject instanceof BaseEntityView) {
					mapFromBaseEntityViewToBaseEntityView(sourceDto, (BaseEntityView) targetObject);
				}
				else if (targetObject instanceof BaseEntity) {
					mapFromBaseEntityViewToBaseEntity(sourceDto, (BaseEntity)targetObject);
				}			   
				else if (targetObject != null) {
					throw new IllegalArgumentException("mapping to object '"+targetObject+"' is not supported");
				}
			}
		};
	}
	
	protected void mapFromBaseEntityViewToBaseEntityView(BaseEntityView sourceDto, BaseEntityView baseEntityView) {
		baseEntityView.setOid(sourceDto.getOid());
		baseEntityView.setVersion(sourceDto.getVersion());
	}
	
	protected BaseEntity mapFromBaseEntityViewToBaseEntity(BaseEntityView sourceDto) {
		return mapFromBaseEntityViewToBaseEntity(sourceDto, MapperContextHolder.createEntity(BaseEntity.class));
	}
	
	protected BaseEntity mapFromBaseEntityViewToBaseEntity(BaseEntityView sourceDto, BaseEntity baseEntity) {
		if (MapperContextHolder.getContext().containsKey(sourceDto)) {
			return (BaseEntity) MapperContextHolder.getContext().get(sourceDto);
		}
		MapperContextHolder.getContext().put(sourceDto, baseEntity);
		if (sourceDto.getOid() != null) {
			baseEntity.setOid(sourceDto.getOid());
		}
		baseEntity.setVersion(sourceDto.getVersion());
		return baseEntity;
	}
	
	protected BaseEntityView mapFromBaseEntityToBaseEntityView(BaseEntity baseEntity) {
		if (MapperContextHolder.getContext().containsKey(baseEntity)) {
			return (BaseEntityView) MapperContextHolder.getContext().get(baseEntity);
		}
		BaseEntityView baseEntityView = new BaseEntityView();
		MapperContextHolder.getContext().put(baseEntity, baseEntityView);
		baseEntityView.setOid(baseEntity.getOid());
		baseEntityView.setVersion(baseEntity.getVersion());
		return baseEntityView;
	}
	
	protected BaseEntityView mapFromBaseEntityToBaseEntityView(BaseEntity baseEntity, BaseEntityView baseEntityView) {
		if (MapperContextHolder.getContext().containsKey(baseEntity)) {
			return (BaseEntityView) MapperContextHolder.getContext().get(baseEntity);
		}
		MapperContextHolder.getContext().put(baseEntity, baseEntityView);
		baseEntityView.setOid(baseEntity.getOid());
		baseEntityView.setVersion(baseEntity.getVersion());
		return baseEntityView;
	}
	
	
	
}
