package org.openxma.dsl.reference.dao;

import org.openxma.dsl.platform.dao.*;
import org.openxma.dsl.reference.dao.BugDao;
import org.openxma.dsl.reference.model.Bug;

/**
 * Represents a Data Access Object, as defined in the
 * Core J2EE Pattern Catalog (see http://java.sun.com/blueprints/corej2eepatterns/Patterns/DataAccessObject.html),
 * to abstract and encapsulate all access to entity BugDao.
 * @see BugDao
 */
public interface BugDaoGen extends GenericDao<Bug,Long>, EntityFactory<Bug> {
	/**
	 * Factory method to create an empty <code>Bug</code> entity with an already assigned identifier.
	 * The advantage of this approach, coupled with the fact that we're using the id for equals,
	 * is that equality test's are immediately possible and therefore independent from the persistence state
	 * of the entity. This in contrast to other solutions where auto generated Keys are used
	 * which must wait until the object is persisted or differentiate between transient and managed states.
	 * @return a new (transient), empty <code>Bug</code> entity with an already assigned identifier.
	 */
	Bug create();
	/**
	 * Factory method to create an empty <code>Bug</code> taking all not null attributes.
	 *
	 * @param bugId
	 * @return a new (transient ) <code>Bug</code> entity with the given natural identifier and not null attributes set.
	 */
	Bug create(String bugId);
	/**
	 * Factory method to create and save an empty <code>Bug</code> taking all not null attributes.
	 *
	 * @param bugId
	 * @return a new (transient) <code>Bug</code> entity with the given natural identifier and not null attributes set.
	 */
	Bug createAndSave(String bugId);
}
