package org.openxma.dsl.reference.dao;

import org.openxma.dsl.platform.dao.*;
import org.openxma.dsl.reference.dao.CategoryDao;
import org.openxma.dsl.reference.model.Category;

/**
 * Represents a Data Access Object, as defined in the
 * Core J2EE Pattern Catalog (see http://java.sun.com/blueprints/corej2eepatterns/Patterns/DataAccessObject.html),
 * to abstract and encapsulate all access to entity CategoryDao.
 * @see CategoryDao
 */
public interface CategoryDaoGen extends GenericDao<Category,Long>, EntityFactory<Category> {
	/**
	 * Factory method to create an empty <code>Category</code> entity with an already assigned identifier.
	 * The advantage of this approach, coupled with the fact that we're using the id for equals,
	 * is that equality test's are immediately possible and therefore independent from the persistence state
	 * of the entity. This in contrast to other solutions where auto generated Keys are used
	 * which must wait until the object is persisted or differentiate between transient and managed states.
	 * @return a new (transient), empty <code>Category</code> entity with an already assigned identifier.
	 */
	Category create();
	/**
	 * Factory method to create an empty <code>Category</code> taking all not null attributes.
	 *
	 * @param name
	 * @return a new (transient ) <code>Category</code> entity with the given natural identifier and not null attributes set.
	 */
	Category create(String name);
	/**
	 * Factory method to create and save an empty <code>Category</code> taking all not null attributes.
	 *
	 * @param name
	 * @return a new (transient) <code>Category</code> entity with the given natural identifier and not null attributes set.
	 */
	Category createAndSave(String name);
}
