package org.openxma.dsl.reference.dao;

import org.openxma.dsl.platform.dao.*;
import java.util.Collection;
import org.openxma.dsl.reference.dao.ProductDao;
import org.openxma.dsl.reference.model.Product;
import org.openxma.dsl.reference.model.Supplier;
import org.openxma.dsl.reference.types.valueobject.ProductId;

/**
*  DAO for products.
*
 * Represents a Data Access Object, as defined in the
 * Core J2EE Pattern Catalog (see http://java.sun.com/blueprints/corej2eepatterns/Patterns/DataAccessObject.html),
 * to abstract and encapsulate all access to entity ProductDao.
 * @see ProductDao
 */
public interface ProductDaoGen extends GenericDao<Product,ProductId>, EntityFactory<Product> {
	/**
	 * Query name constants
	 */
	static final String FIND_PRODUCT0 = "Product.FindProduct0";
	static final String FIND_PRODUCT1 = "Product.FindProduct1";
	/**
	 * Stored procedure name constants
	 */
	/**
	 * Factory method to create an empty <code>Product</code> entity with an already assigned identifier.
	 * The advantage of this approach, coupled with the fact that we're using the id for equals,
	 * is that equality test's are immediately possible and therefore independent from the persistence state
	 * of the entity. This in contrast to other solutions where auto generated Keys are used
	 * which must wait until the object is persisted or differentiate between transient and managed states.
	 * @return a new (transient), empty <code>Product</code> entity with an already assigned identifier.
	 */
	Product create();
	/**
	 * Factory method to create an empty <code>Product</code> taking all not null attributes.
	 *
	 * @param supplier
	 * @param name
	 * @param unitPrice
	 * @return a new (transient ) <code>Product</code> entity with the given natural identifier and not null attributes set.
	 */
	Product create(Supplier supplier,String name,Integer unitPrice);
	/**
	 * Factory method to create and save an empty <code>Product</code> taking all not null attributes.
	 *
	 * @param supplier
	 * @param name
	 * @param unitPrice
	 * @return a new (transient) <code>Product</code> entity with the given natural identifier and not null attributes set.
	 */
	Product createAndSave(Supplier supplier,String name,Integer unitPrice);
	/**
	 *
	 * @param name
	 * @return a collection containing 0 or more persistent Product instances
	 */
	Collection<Product> findProduct(String name);
	/**
	 *
	 * @param name
	 * @param maxUnitPrice
	 * @return a collection containing 0 or more persistent Product instances
	 */
	Collection<Product> findProduct(String name,Integer maxUnitPrice);
}
