package org.openxma.dsl.reference.dao;

import org.openxma.dsl.platform.dao.*;
import java.util.Collection;
import org.openxma.dsl.reference.SupplierAddress;
import org.openxma.dsl.reference.dao.SupplierDao;
import org.openxma.dsl.reference.dto.SupplierNameView;
import org.openxma.dsl.reference.dto.SupplierNameView2;
import org.openxma.dsl.reference.model.Supplier;

/**
 * Represents a Data Access Object, as defined in the
 * Core J2EE Pattern Catalog (see http://java.sun.com/blueprints/corej2eepatterns/Patterns/DataAccessObject.html),
 * to abstract and encapsulate all access to entity SupplierDao.
 * @see SupplierDao
 */
public interface SupplierDaoGen extends GenericDao<Supplier,String>, EntityFactory<Supplier> {
	/**
	 * Query name constants
	 */
	static final String FIND_ALL_BY_COMPANY_NAME = "Supplier.FindAllByCompanyName";
	static final String FIND_ALL_BY_COMPANY_NAME_PAGING = "Supplier.FindAllByCompanyNamePaging";
	static final String GET_SUPPLIER_COUNT = "Supplier.GetSupplierCount";
	static final String FIND_ALL_BY_ADDRESS = "Supplier.FindAllByAddress";
	static final String FIND_WITH_UNUSED_PARAMETER = "Supplier.FindWithUnusedParameter";
	static final String FIND_PRODUCT_SUPPLIERS = "Supplier.FindProductSuppliers";
	static final String FIND_ALL_SUPPLIER_NAMES = "Supplier.FindAllSupplierNames";
	static final String FIND_ALL_SUPPLIER_NAMES2 = "Supplier.FindAllSupplierNames2";
	static final String FIND_ALL_SUPPLIER_NAMES3 = "Supplier.FindAllSupplierNames3";
	/**
	 * Stored procedure name constants
	 */
	/**
	 * Factory method to create an empty <code>Supplier</code> entity with an already assigned identifier.
	 * The advantage of this approach, coupled with the fact that we're using the id for equals,
	 * is that equality test's are immediately possible and therefore independent from the persistence state
	 * of the entity. This in contrast to other solutions where auto generated Keys are used
	 * which must wait until the object is persisted or differentiate between transient and managed states.
	 * @return a new (transient), empty <code>Supplier</code> entity with an already assigned identifier.
	 */
	Supplier create();
	/**
	 * Factory method to create an empty <code>Supplier</code> taking all not null attributes.
	 *
	 * @param companyName
	 * @return a new (transient ) <code>Supplier</code> entity with the given natural identifier and not null attributes set.
	 */
	Supplier create(String companyName);
	/**
	 * Factory method to create and save an empty <code>Supplier</code> taking all not null attributes.
	 *
	 * @param companyName
	 * @return a new (transient) <code>Supplier</code> entity with the given natural identifier and not null attributes set.
	 */
	Supplier createAndSave(String companyName);
	/**
	 * Return the persistent instance of the Supplier entity class
	 * with the given natural identifier or <code>null</code> if not found.
	 *
	 * @param companyName
	 * @return the persistent Supplier instance, or <code>null</code> if not found
	 */
	Supplier loadBySupplierKey(String companyName);
	/**
	 *
	 * @param companyName
	 * @return a collection containing 0 or more persistent SupplierNameView instances
	 */
	Collection<SupplierNameView> findAllByCompanyName(String companyName);
	/**
	 *
	 * @param companyName
	 * @param firstResult
	 * @param maxResults
	 * @return a collection containing 0 or more persistent SupplierNameView instances
	 */
	Collection<SupplierNameView> findAllByCompanyNamePaging(String companyName,Integer firstResult,Integer maxResults);
	/**
	 *
	 * @return the long instance, or <code>null</code> if not found
	 */
	Long getSupplierCount();
	/**
	 *
	 * @param address
	 * @return a collection containing 0 or more persistent Supplier instances
	 */
	Collection<Supplier> findAllByAddress(SupplierAddress address);
	/**
	 *
	 * @param companyName
	 * @param code
	 * @return a collection containing 0 or more persistent Supplier instances
	 */
	Collection<Supplier> findWithUnusedParameter(String companyName,String code);
	/**
	 *
	 * @return a collection containing 0 or more persistent Supplier instances
	 */
	Collection<Supplier> findProductSuppliers();
	/**
	 *
	 * @return a collection containing 0 or more persistent SupplierNameView2 instances
	 */
	Collection<SupplierNameView2> findAllSupplierNames();
	/**
	 *
	 * @return a collection containing 0 or more persistent SupplierNameView instances
	 */
	Collection<SupplierNameView> findAllSupplierNames2();
	/**
	 *
	 * @return a collection containing 0 or more persistent SupplierNameView2 instances
	 */
	Collection<SupplierNameView2> findAllSupplierNames3();
}
