package org.openxma.dsl.reference.dtoassembler.service.impl;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.openxma.dsl.platform.service.Mapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.openxma.dsl.reference.dtoassembler.dao.ChildDao;
import org.openxma.dsl.reference.dtoassembler.dao.ParentDao;
import org.openxma.dsl.reference.dtoassembler.dto.ChildView;
import org.openxma.dsl.reference.dtoassembler.dto.ParentView;
import org.openxma.dsl.reference.dtoassembler.model.Child;
import org.openxma.dsl.reference.dtoassembler.model.Parent;
import org.openxma.dsl.reference.dtoassembler.service.ParentService;
import org.springframework.dao.OptimisticLockingFailureException;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.Assert;
public abstract class ParentServiceGenImpl implements ParentService {
	protected final Log logger = LogFactory.getLog(getClass());
	@Autowired(required=false)
	protected Mapper mapper;
	protected ParentDao parentDao;
	protected ChildDao childDao;
	
	@Autowired
	public void setParentDao(ParentDao parentDao) {
		this.parentDao = parentDao;
	}
	
	@Autowired
	public void setChildDao(ChildDao childDao) {
		this.childDao = childDao;
	}
	
	@Transactional
	public ParentView save(ParentView parentView) {
		Assert.notNull(parentView, "parameter 'parentView' must not be null");
		Parent parent = this.mapper.createAndMapOne(parentView, Parent.class,"saveParent");
		addChildren(parent,parentView);
		this.parentDao.saveOrUpdate(parent);
		return this.mapper.mapOne(parent,new ParentView());
	}
	
	private void addChildren(Parent parentParent,ParentView parentView) {
		if (parentView.getChildren() != null) {
			for (ChildView _childView : parentView.getChildren()) {
				Child child = this.mapper.createAndMapOne(_childView, Child.class,"saveChild");
				parentParent.addChildren(child);
			}
		}
	}
	
	@Transactional(readOnly = true)
	public ParentView loadParentView(String oid) {
		Assert.notNull(oid, "parameter 'oid' must not be null");
		return this.mapper.createAndMapOne(this.parentDao.load(oid),ParentView.class);
	}
	
	@Transactional
	public void update(ParentView parentView) {
		Assert.notNull(parentView, "parameter 'parentView' must not be null");
		Parent mappedParent = this.mapper.createAndMapOne(parentView, Parent.class);
		Parent parent = this.parentDao.load(mappedParent.getOid());
		if (!parent.getVersion().equals(mappedParent.getVersion())) {
			throw new OptimisticLockingFailureException("Entity 'Parent' was updated or deleted by another transaction.");
		}
		this.mapper.mapOne(parentView, parent,"updateParent");
	}
	
	@Transactional
	public void deleteParent(String oid) {
		Assert.notNull(oid, "parameter 'oid' must not be null");
		this.parentDao.delete(oid);
	}
	
	@Transactional
	public ParentView saveOrUpdate(ParentView parentView) {
		Assert.notNull(parentView, "parameter 'parentView' must not be null");
		if ( parentView.getVersion() == null ) {
			return this.save(parentView);
		}
		else {
			this.update(parentView);
			return parentView;
		}
	}
	
	
}
