package org.openxma.dsl.reference.mappertest;

import org.openxma.dsl.platform.service.MapperContextHolder;
import java.math.BigDecimal;
import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import org.openxma.dsl.platform.assembler.DtoAssembler;
import org.openxma.dsl.platform.assembler.DtoAssemblerFactory;
import org.openxma.dsl.platform.assembler.DtoAssemblerRegistry;
import org.openxma.dsl.platform.converter.Converter;
import org.openxma.dsl.reference.mappertest.dto.PersonNameView;
import org.openxma.dsl.reference.mappertest.dto.PersonView;
import org.openxma.dsl.reference.mappertest.model.Person;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.Assert;

public class DtoAssemblerFactoryMappertestGen implements DtoAssemblerFactory {

	private List<DtoAssembler<?>> dtoAssemblers;

	@Autowired
	private DtoAssemblerRegistry dtoAssemblerRegistry;
	
	@Autowired
	private Converter converter;

	public DtoAssemblerFactoryMappertestGen() {
		dtoAssemblers = new ArrayList<DtoAssembler<?>>(2);
		initDtoAssemblers();
	}


	public List<DtoAssembler<?>> getDtoAssemblers() {
		return dtoAssemblers;
	}

	protected DtoAssemblerRegistry getDtoAssemblerRegistry() {
		return dtoAssemblerRegistry;
	}
	
	protected Converter getConverter() {
		return converter;
	}

	private void initDtoAssemblers() {
		dtoAssemblers.add(createDtoAssemblerPersonNameView());
		dtoAssemblers.add(createDtoAssemblerPersonView());
	}


	private DtoAssembler<PersonNameView> createDtoAssemblerPersonNameView() {
		return new DtoAssembler<PersonNameView>() {
			public PersonNameView mapFromEntity(Object sourceEntity) {
				Assert.notNull(sourceEntity, "parameter 'sourceEntity' must not be null");
				if (sourceEntity instanceof Person) {
					Person person = (Person) sourceEntity;
					PersonNameView result = mapFromPersonToPersonNameView(person);
					return result;
				}
				throw new IllegalArgumentException("mapping from object '"+sourceEntity+"' is not supported");
					
			}
			
			public PersonNameView mapFromEntity(Object sourceEntity, PersonNameView targetDto) {
				Assert.notNull(sourceEntity, "parameter 'sourceEntity' must not be null");
				Assert.notNull(targetDto, "parameter 'targetDto' must not be null");
				if (sourceEntity instanceof Person) {
					Person person = (Person) sourceEntity;
					mapFromPersonToPersonNameView(person, targetDto);
					return targetDto;
				}
				throw new IllegalArgumentException("mapping from object '"+sourceEntity+"' is not supported");
					
			}
			
			public <T> T mapTo(PersonNameView sourceDto, Class<T> target) {
				if (PersonNameView.class.equals(target)) {
					PersonNameView result = new PersonNameView();
					mapFromPersonNameViewToPersonNameView(sourceDto, result);
					return target.cast(result);
				}
				else if (PersonView.class.equals(target) && MapperContextHolder.getContext().containsKey("mapper:TestMapper1")) {
					return target.cast(mapperTestMapper1MapsFromPersonNameViewToPersonView(sourceDto));
				}
				
				else if (PersonView.class.equals(target) && MapperContextHolder.getContext().containsKey("mapper:TestMapper10")) {
					return target.cast(mapperTestMapper10MapsFromPersonNameViewToPersonView(sourceDto));
				}
				
				//dataView: 'PersonNameView' is not a mapping source in mapper: 'TestMapper2'
				
				else if (PersonView.class.equals(target) && MapperContextHolder.getContext().containsKey("mapper:TestMapper3")) {
					return target.cast(mapperTestMapper3MapsFromPersonNameViewToPersonView(sourceDto));
				}
				
				else if (PersonView.class.equals(target) && MapperContextHolder.getContext().containsKey("mapper:TestMapper4")) {
					return target.cast(mapperTestMapper4MapsFromPersonNameViewToPersonView(sourceDto));
				}
				
				//dataView: 'PersonNameView' is not a mapping source in mapper: 'TestMapper5'
				
				else if (PersonView.class.equals(target) && MapperContextHolder.getContext().containsKey("mapper:TestMapper6")) {
					return target.cast(mapperTestMapper6MapsFromPersonNameViewToPersonView(sourceDto));
				}
				
				else if (PersonView.class.equals(target) && MapperContextHolder.getContext().containsKey("mapper:TestMapper7")) {
					return target.cast(mapperTestMapper7MapsFromPersonNameViewToPersonView(sourceDto));
				}
				
				//dataView: 'PersonNameView' is not a mapping source in mapper: 'TestMapper8'
				
				else if (PersonView.class.equals(target) && MapperContextHolder.getContext().containsKey("mapper:TestMapper9")) {
					return target.cast(mapperTestMapper9MapsFromPersonNameViewToPersonView(sourceDto));
				}
				
				else if (Person.class.equals(target)) {
					return target.cast(mapFromPersonNameViewToPerson(sourceDto));
				}
				else {
					throw new IllegalArgumentException("mapping to class '"+target+"' is not supported");
				}
			}
			
			public void mapTo(PersonNameView sourceDto, Object targetObject) {
				if (targetObject instanceof PersonNameView) {
					mapFromPersonNameViewToPersonNameView(sourceDto, (PersonNameView) targetObject);
				}
				else if (targetObject instanceof PersonView && MapperContextHolder.getContext().containsKey("mapper:TestMapper1")) {
					mapperTestMapper1MapsFromPersonNameViewToPersonView(sourceDto, (PersonView)targetObject);
				}
				
				else if (targetObject instanceof PersonView && MapperContextHolder.getContext().containsKey("mapper:TestMapper10")) {
					mapperTestMapper10MapsFromPersonNameViewToPersonView(sourceDto, (PersonView)targetObject);
				}
				
				//dataView: 'PersonNameView' is not a mapping source in mapper: 'TestMapper2'
				
				else if (targetObject instanceof PersonView && MapperContextHolder.getContext().containsKey("mapper:TestMapper3")) {
					mapperTestMapper3MapsFromPersonNameViewToPersonView(sourceDto, (PersonView)targetObject);
				}
				
				else if (targetObject instanceof PersonView && MapperContextHolder.getContext().containsKey("mapper:TestMapper4")) {
					mapperTestMapper4MapsFromPersonNameViewToPersonView(sourceDto, (PersonView)targetObject);
				}
				
				//dataView: 'PersonNameView' is not a mapping source in mapper: 'TestMapper5'
				
				else if (targetObject instanceof PersonView && MapperContextHolder.getContext().containsKey("mapper:TestMapper6")) {
					mapperTestMapper6MapsFromPersonNameViewToPersonView(sourceDto, (PersonView)targetObject);
				}
				
				else if (targetObject instanceof PersonView && MapperContextHolder.getContext().containsKey("mapper:TestMapper7")) {
					mapperTestMapper7MapsFromPersonNameViewToPersonView(sourceDto, (PersonView)targetObject);
				}
				
				//dataView: 'PersonNameView' is not a mapping source in mapper: 'TestMapper8'
				
				else if (targetObject instanceof PersonView && MapperContextHolder.getContext().containsKey("mapper:TestMapper9")) {
					mapperTestMapper9MapsFromPersonNameViewToPersonView(sourceDto, (PersonView)targetObject);
				}
				
				else if (targetObject instanceof Person) {
					mapFromPersonNameViewToPerson(sourceDto, (Person)targetObject);
				}			   
				else if (targetObject != null) {
					throw new IllegalArgumentException("mapping to object '"+targetObject+"' is not supported");
				}
			}
		};
	}
	
	protected void mapFromPersonNameViewToPersonNameView(PersonNameView sourceDto, PersonNameView personNameView) {
		personNameView.setFirstName(sourceDto.getFirstName());
		personNameView.setLastName(sourceDto.getLastName());
	}
	
	protected Person mapFromPersonNameViewToPerson(PersonNameView sourceDto) {
		return mapFromPersonNameViewToPerson(sourceDto, MapperContextHolder.createEntity(Person.class));
	}
	
	protected Person mapFromPersonNameViewToPerson(PersonNameView sourceDto, Person person) {
		if (MapperContextHolder.getContext().containsKey(sourceDto)) {
			return (Person) MapperContextHolder.getContext().get(sourceDto);
		}
		MapperContextHolder.getContext().put(sourceDto, person);
		person.setFirstName(sourceDto.getFirstName());
		person.setLastName(sourceDto.getLastName());
		return person;
	}
	
	protected PersonNameView mapFromPersonToPersonNameView(Person person) {
		if (MapperContextHolder.getContext().containsKey(person)) {
			return (PersonNameView) MapperContextHolder.getContext().get(person);
		}
		PersonNameView personNameView = new PersonNameView();
		MapperContextHolder.getContext().put(person, personNameView);
		personNameView.setFirstName(person.getFirstName());
		personNameView.setLastName(person.getLastName());
		return personNameView;
	}
	
	protected PersonNameView mapFromPersonToPersonNameView(Person person, PersonNameView personNameView) {
		if (MapperContextHolder.getContext().containsKey(person)) {
			return (PersonNameView) MapperContextHolder.getContext().get(person);
		}
		MapperContextHolder.getContext().put(person, personNameView);
		personNameView.setFirstName(person.getFirstName());
		personNameView.setLastName(person.getLastName());
		return personNameView;
	}
	
	
	protected PersonView mapperTestMapper1MapsFromPersonNameViewToPersonView(PersonNameView sourceDto) {
		PersonView target = MapperContextHolder.createComplexType(PersonView.class);
		mapperTestMapper1MapsFromPersonNameViewToPersonView(sourceDto, target);
		return target;
	}
	
	protected void mapperTestMapper1MapsFromPersonNameViewToPersonView(PersonNameView sourceDto, PersonView target ) {
	target.setBirthDate(converter.convert(Date.class, sourceDto.getBirthDate()));
	target.setBigDecimalTest(converter.convert(BigDecimal.class, sourceDto.getBigDecimalTest()));
	target.setBooleanTest(converter.convert(Boolean.class, sourceDto.getBooleanTest()));
	target.setDoubleTest(converter.convert(Double.class, sourceDto.getDoubleTest()));
	target.setFloatTest(converter.convert(Float.class, sourceDto.getFloatTest()));
	target.setIntegerTest(converter.convert(Integer.class, sourceDto.getIntegerTest()));
	target.setLongTest(converter.convert(Long.class, sourceDto.getLongTest()));
	target.setTimestampTest(converter.convert(Timestamp.class, sourceDto.getTimestampTest()));
	target.setEmailAddress(sourceDto.getEmailAddress());
	target.setOid(sourceDto.getOid());
	target.setVersion(sourceDto.getVersion());
	target.setFirstName(sourceDto.getFirstName());
	target.setLastName(sourceDto.getLastName());
	target.setReadOnlyName(sourceDto.getReadOnlyName());
	}
	
	protected PersonView mapperTestMapper10MapsFromPersonNameViewToPersonView(PersonNameView sourceDto) {
		PersonView target = MapperContextHolder.createComplexType(PersonView.class);
		mapperTestMapper10MapsFromPersonNameViewToPersonView(sourceDto, target);
		return target;
	}
	
	protected void mapperTestMapper10MapsFromPersonNameViewToPersonView(PersonNameView sourceDto, PersonView target ) {
		target.setFirstName(sourceDto.getLastName());
		target.setEmailAddress(sourceDto.getEmailAddress());
	}
	
	protected PersonView mapperTestMapper2MapsFromPersonNameViewToPersonView(PersonNameView sourceDto) {
		PersonView target = MapperContextHolder.createComplexType(PersonView.class);
		mapperTestMapper2MapsFromPersonNameViewToPersonView(sourceDto, target);
		return target;
	}
	
	protected void mapperTestMapper2MapsFromPersonNameViewToPersonView(PersonNameView sourceDto, PersonView target ) {
	}
	
	protected PersonView mapperTestMapper3MapsFromPersonNameViewToPersonView(PersonNameView sourceDto) {
		PersonView target = MapperContextHolder.createComplexType(PersonView.class);
		mapperTestMapper3MapsFromPersonNameViewToPersonView(sourceDto, target);
		return target;
	}
	
	protected void mapperTestMapper3MapsFromPersonNameViewToPersonView(PersonNameView sourceDto, PersonView target ) {
	target.setBirthDate(converter.convert(Date.class, sourceDto.getBirthDate()));
	target.setBigDecimalTest(converter.convert(BigDecimal.class, sourceDto.getBigDecimalTest()));
	target.setBooleanTest(converter.convert(Boolean.class, sourceDto.getBooleanTest()));
	target.setDoubleTest(converter.convert(Double.class, sourceDto.getDoubleTest()));
	target.setFloatTest(converter.convert(Float.class, sourceDto.getFloatTest()));
	target.setIntegerTest(converter.convert(Integer.class, sourceDto.getIntegerTest()));
	target.setLongTest(converter.convert(Long.class, sourceDto.getLongTest()));
	target.setTimestampTest(converter.convert(Timestamp.class, sourceDto.getTimestampTest()));
	target.setEmailAddress(sourceDto.getEmailAddress());
	target.setOid(sourceDto.getOid());
	target.setVersion(sourceDto.getVersion());
	target.setFirstName(sourceDto.getFirstName());
	target.setLastName(sourceDto.getLastName());
	target.setReadOnlyName(sourceDto.getReadOnlyName());
	}
	
	protected PersonView mapperTestMapper4MapsFromPersonNameViewToPersonView(PersonNameView sourceDto) {
		PersonView target = MapperContextHolder.createComplexType(PersonView.class);
		mapperTestMapper4MapsFromPersonNameViewToPersonView(sourceDto, target);
		return target;
	}
	
	protected void mapperTestMapper4MapsFromPersonNameViewToPersonView(PersonNameView sourceDto, PersonView target ) {
		target.setEmailAddress(sourceDto.getEmailAddress());
	}
	
	protected PersonView mapperTestMapper5MapsFromPersonNameViewToPersonView(PersonNameView sourceDto) {
		PersonView target = MapperContextHolder.createComplexType(PersonView.class);
		mapperTestMapper5MapsFromPersonNameViewToPersonView(sourceDto, target);
		return target;
	}
	
	protected void mapperTestMapper5MapsFromPersonNameViewToPersonView(PersonNameView sourceDto, PersonView target ) {
	}
	
	protected PersonView mapperTestMapper6MapsFromPersonNameViewToPersonView(PersonNameView sourceDto) {
		PersonView target = MapperContextHolder.createComplexType(PersonView.class);
		mapperTestMapper6MapsFromPersonNameViewToPersonView(sourceDto, target);
		return target;
	}
	
	protected void mapperTestMapper6MapsFromPersonNameViewToPersonView(PersonNameView sourceDto, PersonView target ) {
		target.setEmailAddress(sourceDto.getEmailAddress());
	}
	
	protected PersonView mapperTestMapper7MapsFromPersonNameViewToPersonView(PersonNameView sourceDto) {
		PersonView target = MapperContextHolder.createComplexType(PersonView.class);
		mapperTestMapper7MapsFromPersonNameViewToPersonView(sourceDto, target);
		return target;
	}
	
	protected void mapperTestMapper7MapsFromPersonNameViewToPersonView(PersonNameView sourceDto, PersonView target ) {
		target.setEmailAddress(sourceDto.getEmailAddress());
	}
	
	protected PersonView mapperTestMapper8MapsFromPersonNameViewToPersonView(PersonNameView sourceDto) {
		PersonView target = MapperContextHolder.createComplexType(PersonView.class);
		mapperTestMapper8MapsFromPersonNameViewToPersonView(sourceDto, target);
		return target;
	}
	
	protected void mapperTestMapper8MapsFromPersonNameViewToPersonView(PersonNameView sourceDto, PersonView target ) {
	}
	
	protected PersonView mapperTestMapper9MapsFromPersonNameViewToPersonView(PersonNameView sourceDto) {
		PersonView target = MapperContextHolder.createComplexType(PersonView.class);
		mapperTestMapper9MapsFromPersonNameViewToPersonView(sourceDto, target);
		return target;
	}
	
	protected void mapperTestMapper9MapsFromPersonNameViewToPersonView(PersonNameView sourceDto, PersonView target ) {
		target.setFirstName(sourceDto.getLastName());
	}
	
	
	private DtoAssembler<PersonView> createDtoAssemblerPersonView() {
		return new DtoAssembler<PersonView>() {
			public PersonView mapFromEntity(Object sourceEntity) {
				Assert.notNull(sourceEntity, "parameter 'sourceEntity' must not be null");
				if (sourceEntity instanceof Person) {
					Person person = (Person) sourceEntity;
					PersonView result = mapFromPersonToPersonView(person);
					return result;
				}
				throw new IllegalArgumentException("mapping from object '"+sourceEntity+"' is not supported");
					
			}
			
			public PersonView mapFromEntity(Object sourceEntity, PersonView targetDto) {
				Assert.notNull(sourceEntity, "parameter 'sourceEntity' must not be null");
				Assert.notNull(targetDto, "parameter 'targetDto' must not be null");
				if (sourceEntity instanceof Person) {
					Person person = (Person) sourceEntity;
					mapFromPersonToPersonView(person, targetDto);
					return targetDto;
				}
				throw new IllegalArgumentException("mapping from object '"+sourceEntity+"' is not supported");
					
			}
			
			public <T> T mapTo(PersonView sourceDto, Class<T> target) {
				if (PersonView.class.equals(target)) {
					PersonView result = new PersonView();
					mapFromPersonViewToPersonView(sourceDto, result);
					return target.cast(result);
				}
				else if (PersonNameView.class.equals(target) && MapperContextHolder.getContext().containsKey("mapper:TestMapper1")) {
					return target.cast(mapperTestMapper1MapsFromPersonViewToPersonNameView(sourceDto));
				}
				
				else if (PersonNameView.class.equals(target) && MapperContextHolder.getContext().containsKey("mapper:TestMapper10")) {
					return target.cast(mapperTestMapper10MapsFromPersonViewToPersonNameView(sourceDto));
				}
				
				else if (PersonNameView.class.equals(target) && MapperContextHolder.getContext().containsKey("mapper:TestMapper2")) {
					return target.cast(mapperTestMapper2MapsFromPersonViewToPersonNameView(sourceDto));
				}
				
				//dataView: 'PersonView' is not a mapping source in mapper: 'TestMapper3'
				
				else if (PersonNameView.class.equals(target) && MapperContextHolder.getContext().containsKey("mapper:TestMapper4")) {
					return target.cast(mapperTestMapper4MapsFromPersonViewToPersonNameView(sourceDto));
				}
				
				else if (PersonNameView.class.equals(target) && MapperContextHolder.getContext().containsKey("mapper:TestMapper5")) {
					return target.cast(mapperTestMapper5MapsFromPersonViewToPersonNameView(sourceDto));
				}
				
				//dataView: 'PersonView' is not a mapping source in mapper: 'TestMapper6'
				
				//dataView: 'PersonView' is not a mapping source in mapper: 'TestMapper7'
				
				else if (PersonNameView.class.equals(target) && MapperContextHolder.getContext().containsKey("mapper:TestMapper8")) {
					return target.cast(mapperTestMapper8MapsFromPersonViewToPersonNameView(sourceDto));
				}
				
				else if (PersonNameView.class.equals(target) && MapperContextHolder.getContext().containsKey("mapper:TestMapper9")) {
					return target.cast(mapperTestMapper9MapsFromPersonViewToPersonNameView(sourceDto));
				}
				
				else if (Person.class.equals(target)) {
					return target.cast(mapFromPersonViewToPerson(sourceDto));
				}
				else {
					throw new IllegalArgumentException("mapping to class '"+target+"' is not supported");
				}
			}
			
			public void mapTo(PersonView sourceDto, Object targetObject) {
				if (targetObject instanceof PersonView) {
					mapFromPersonViewToPersonView(sourceDto, (PersonView) targetObject);
				}
				else if (targetObject instanceof PersonNameView && MapperContextHolder.getContext().containsKey("mapper:TestMapper1")) {
					mapperTestMapper1MapsFromPersonViewToPersonNameView(sourceDto, (PersonNameView)targetObject);
				}
				
				else if (targetObject instanceof PersonNameView && MapperContextHolder.getContext().containsKey("mapper:TestMapper10")) {
					mapperTestMapper10MapsFromPersonViewToPersonNameView(sourceDto, (PersonNameView)targetObject);
				}
				
				else if (targetObject instanceof PersonNameView && MapperContextHolder.getContext().containsKey("mapper:TestMapper2")) {
					mapperTestMapper2MapsFromPersonViewToPersonNameView(sourceDto, (PersonNameView)targetObject);
				}
				
				//dataView: 'PersonView' is not a mapping source in mapper: 'TestMapper3'
				
				else if (targetObject instanceof PersonNameView && MapperContextHolder.getContext().containsKey("mapper:TestMapper4")) {
					mapperTestMapper4MapsFromPersonViewToPersonNameView(sourceDto, (PersonNameView)targetObject);
				}
				
				else if (targetObject instanceof PersonNameView && MapperContextHolder.getContext().containsKey("mapper:TestMapper5")) {
					mapperTestMapper5MapsFromPersonViewToPersonNameView(sourceDto, (PersonNameView)targetObject);
				}
				
				//dataView: 'PersonView' is not a mapping source in mapper: 'TestMapper6'
				
				//dataView: 'PersonView' is not a mapping source in mapper: 'TestMapper7'
				
				else if (targetObject instanceof PersonNameView && MapperContextHolder.getContext().containsKey("mapper:TestMapper8")) {
					mapperTestMapper8MapsFromPersonViewToPersonNameView(sourceDto, (PersonNameView)targetObject);
				}
				
				else if (targetObject instanceof PersonNameView && MapperContextHolder.getContext().containsKey("mapper:TestMapper9")) {
					mapperTestMapper9MapsFromPersonViewToPersonNameView(sourceDto, (PersonNameView)targetObject);
				}
				
				else if (targetObject instanceof Person) {
					mapFromPersonViewToPerson(sourceDto, (Person)targetObject);
				}			   
				else if (targetObject != null) {
					throw new IllegalArgumentException("mapping to object '"+targetObject+"' is not supported");
				}
			}
		};
	}
	
	protected void mapFromPersonViewToPersonView(PersonView sourceDto, PersonView personView) {
		personView.setOid(sourceDto.getOid());
		personView.setVersion(sourceDto.getVersion());
		personView.setFirstName(sourceDto.getFirstName());
		personView.setLastName(sourceDto.getLastName());
		personView.setEmailAddress(sourceDto.getEmailAddress());
		personView.setBirthDate(sourceDto.getBirthDate());
		personView.setBigDecimalTest(sourceDto.getBigDecimalTest());
		personView.setBooleanTest(sourceDto.getBooleanTest());
		personView.setDoubleTest(sourceDto.getDoubleTest());
		personView.setFloatTest(sourceDto.getFloatTest());
		personView.setIntegerTest(sourceDto.getIntegerTest());
		personView.setLongTest(sourceDto.getLongTest());
		personView.setTimestampTest(sourceDto.getTimestampTest());
	}
	
	protected Person mapFromPersonViewToPerson(PersonView sourceDto) {
		return mapFromPersonViewToPerson(sourceDto, MapperContextHolder.createEntity(Person.class));
	}
	
	protected Person mapFromPersonViewToPerson(PersonView sourceDto, Person person) {
		if (MapperContextHolder.getContext().containsKey(sourceDto)) {
			return (Person) MapperContextHolder.getContext().get(sourceDto);
		}
		MapperContextHolder.getContext().put(sourceDto, person);
		if (sourceDto.getOid() != null) {
			person.setOid(sourceDto.getOid());
		}
		person.setVersion(sourceDto.getVersion());
		person.setFirstName(sourceDto.getFirstName());
		person.setLastName(sourceDto.getLastName());
		person.setEmailAddress(sourceDto.getEmailAddress());
		person.setBirthDate(sourceDto.getBirthDate());
		person.setBigDecimalTest(sourceDto.getBigDecimalTest());
		person.setBooleanTest(sourceDto.getBooleanTest());
		person.setDoubleTest(sourceDto.getDoubleTest());
		person.setFloatTest(sourceDto.getFloatTest());
		person.setIntegerTest(sourceDto.getIntegerTest());
		person.setLongTest(sourceDto.getLongTest());
		person.setTimestampTest(sourceDto.getTimestampTest());
		return person;
	}
	
	protected PersonView mapFromPersonToPersonView(Person person) {
		if (MapperContextHolder.getContext().containsKey(person)) {
			return (PersonView) MapperContextHolder.getContext().get(person);
		}
		PersonView personView = new PersonView();
		MapperContextHolder.getContext().put(person, personView);
		personView.setOid(person.getOid());
		personView.setVersion(person.getVersion());
		personView.setFirstName(person.getFirstName());
		personView.setLastName(person.getLastName());
		personView.setEmailAddress(person.getEmailAddress());
		personView.setBirthDate(person.getBirthDate());
		personView.setBigDecimalTest(person.getBigDecimalTest());
		personView.setBooleanTest(person.getBooleanTest());
		personView.setDoubleTest(person.getDoubleTest());
		personView.setFloatTest(person.getFloatTest());
		personView.setIntegerTest(person.getIntegerTest());
		personView.setLongTest(person.getLongTest());
		personView.setTimestampTest(person.getTimestampTest());
		return personView;
	}
	
	protected PersonView mapFromPersonToPersonView(Person person, PersonView personView) {
		if (MapperContextHolder.getContext().containsKey(person)) {
			return (PersonView) MapperContextHolder.getContext().get(person);
		}
		MapperContextHolder.getContext().put(person, personView);
		personView.setOid(person.getOid());
		personView.setVersion(person.getVersion());
		personView.setFirstName(person.getFirstName());
		personView.setLastName(person.getLastName());
		personView.setEmailAddress(person.getEmailAddress());
		personView.setBirthDate(person.getBirthDate());
		personView.setBigDecimalTest(person.getBigDecimalTest());
		personView.setBooleanTest(person.getBooleanTest());
		personView.setDoubleTest(person.getDoubleTest());
		personView.setFloatTest(person.getFloatTest());
		personView.setIntegerTest(person.getIntegerTest());
		personView.setLongTest(person.getLongTest());
		personView.setTimestampTest(person.getTimestampTest());
		return personView;
	}
	
	
	protected PersonNameView mapperTestMapper1MapsFromPersonViewToPersonNameView(PersonView sourceDto) {
		PersonNameView target = MapperContextHolder.createComplexType(PersonNameView.class);
		mapperTestMapper1MapsFromPersonViewToPersonNameView(sourceDto, target);
		return target;
	}
	
	protected void mapperTestMapper1MapsFromPersonViewToPersonNameView(PersonView sourceDto, PersonNameView target ) {
	target.setOid(sourceDto.getOid());
	target.setVersion(sourceDto.getVersion());
	target.setFirstName(sourceDto.getFirstName());
	target.setReadOnlyName(sourceDto.getReadOnlyName());
	target.setLastName(sourceDto.getLastName());
	target.setEmailAddress(sourceDto.getEmailAddress());
	target.setBirthDate(converter.convert(String.class, sourceDto.getBirthDate()));
	target.setBigDecimalTest(converter.convert(String.class, sourceDto.getBigDecimalTest()));
	target.setBooleanTest(converter.convert(String.class, sourceDto.getBooleanTest()));
	target.setDoubleTest(converter.convert(String.class, sourceDto.getDoubleTest()));
	target.setFloatTest(converter.convert(String.class, sourceDto.getFloatTest()));
	target.setIntegerTest(converter.convert(String.class, sourceDto.getIntegerTest()));
	target.setLongTest(converter.convert(String.class, sourceDto.getLongTest()));
	target.setTimestampTest(converter.convert(String.class, sourceDto.getTimestampTest()));
	}
	
	protected PersonNameView mapperTestMapper10MapsFromPersonViewToPersonNameView(PersonView sourceDto) {
		PersonNameView target = MapperContextHolder.createComplexType(PersonNameView.class);
		mapperTestMapper10MapsFromPersonViewToPersonNameView(sourceDto, target);
		return target;
	}
	
	protected void mapperTestMapper10MapsFromPersonViewToPersonNameView(PersonView sourceDto, PersonNameView target ) {
		target.setEmailAddress(sourceDto.getEmailAddress());
		target.setLastName(sourceDto.getFirstName());
		target.setBirthDate(converter.convert(String.class, sourceDto.getBirthDate()));
	}
	
	protected PersonNameView mapperTestMapper2MapsFromPersonViewToPersonNameView(PersonView sourceDto) {
		PersonNameView target = MapperContextHolder.createComplexType(PersonNameView.class);
		mapperTestMapper2MapsFromPersonViewToPersonNameView(sourceDto, target);
		return target;
	}
	
	protected void mapperTestMapper2MapsFromPersonViewToPersonNameView(PersonView sourceDto, PersonNameView target ) {
	target.setOid(sourceDto.getOid());
	target.setVersion(sourceDto.getVersion());
	target.setFirstName(sourceDto.getFirstName());
	target.setReadOnlyName(sourceDto.getReadOnlyName());
	target.setLastName(sourceDto.getLastName());
	target.setEmailAddress(sourceDto.getEmailAddress());
	target.setBirthDate(converter.convert(String.class, sourceDto.getBirthDate()));
	target.setBigDecimalTest(converter.convert(String.class, sourceDto.getBigDecimalTest()));
	target.setBooleanTest(converter.convert(String.class, sourceDto.getBooleanTest()));
	target.setDoubleTest(converter.convert(String.class, sourceDto.getDoubleTest()));
	target.setFloatTest(converter.convert(String.class, sourceDto.getFloatTest()));
	target.setIntegerTest(converter.convert(String.class, sourceDto.getIntegerTest()));
	target.setLongTest(converter.convert(String.class, sourceDto.getLongTest()));
	target.setTimestampTest(converter.convert(String.class, sourceDto.getTimestampTest()));
	}
	
	protected PersonNameView mapperTestMapper3MapsFromPersonViewToPersonNameView(PersonView sourceDto) {
		PersonNameView target = MapperContextHolder.createComplexType(PersonNameView.class);
		mapperTestMapper3MapsFromPersonViewToPersonNameView(sourceDto, target);
		return target;
	}
	
	protected void mapperTestMapper3MapsFromPersonViewToPersonNameView(PersonView sourceDto, PersonNameView target ) {
	}
	
	protected PersonNameView mapperTestMapper4MapsFromPersonViewToPersonNameView(PersonView sourceDto) {
		PersonNameView target = MapperContextHolder.createComplexType(PersonNameView.class);
		mapperTestMapper4MapsFromPersonViewToPersonNameView(sourceDto, target);
		return target;
	}
	
	protected void mapperTestMapper4MapsFromPersonViewToPersonNameView(PersonView sourceDto, PersonNameView target ) {
		target.setEmailAddress(sourceDto.getEmailAddress());
	}
	
	protected PersonNameView mapperTestMapper5MapsFromPersonViewToPersonNameView(PersonView sourceDto) {
		PersonNameView target = MapperContextHolder.createComplexType(PersonNameView.class);
		mapperTestMapper5MapsFromPersonViewToPersonNameView(sourceDto, target);
		return target;
	}
	
	protected void mapperTestMapper5MapsFromPersonViewToPersonNameView(PersonView sourceDto, PersonNameView target ) {
		target.setEmailAddress(sourceDto.getEmailAddress());
	}
	
	protected PersonNameView mapperTestMapper6MapsFromPersonViewToPersonNameView(PersonView sourceDto) {
		PersonNameView target = MapperContextHolder.createComplexType(PersonNameView.class);
		mapperTestMapper6MapsFromPersonViewToPersonNameView(sourceDto, target);
		return target;
	}
	
	protected void mapperTestMapper6MapsFromPersonViewToPersonNameView(PersonView sourceDto, PersonNameView target ) {
	}
	
	protected PersonNameView mapperTestMapper7MapsFromPersonViewToPersonNameView(PersonView sourceDto) {
		PersonNameView target = MapperContextHolder.createComplexType(PersonNameView.class);
		mapperTestMapper7MapsFromPersonViewToPersonNameView(sourceDto, target);
		return target;
	}
	
	protected void mapperTestMapper7MapsFromPersonViewToPersonNameView(PersonView sourceDto, PersonNameView target ) {
	}
	
	protected PersonNameView mapperTestMapper8MapsFromPersonViewToPersonNameView(PersonView sourceDto) {
		PersonNameView target = MapperContextHolder.createComplexType(PersonNameView.class);
		mapperTestMapper8MapsFromPersonViewToPersonNameView(sourceDto, target);
		return target;
	}
	
	protected void mapperTestMapper8MapsFromPersonViewToPersonNameView(PersonView sourceDto, PersonNameView target ) {
		target.setEmailAddress(sourceDto.getEmailAddress());
	}
	
	protected PersonNameView mapperTestMapper9MapsFromPersonViewToPersonNameView(PersonView sourceDto) {
		PersonNameView target = MapperContextHolder.createComplexType(PersonNameView.class);
		mapperTestMapper9MapsFromPersonViewToPersonNameView(sourceDto, target);
		return target;
	}
	
	protected void mapperTestMapper9MapsFromPersonViewToPersonNameView(PersonView sourceDto, PersonNameView target ) {
		target.setEmailAddress(sourceDto.getEmailAddress());
	}
	
	
}
