package org.openxma.dsl.reference.service.impl;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.openxma.dsl.platform.service.Mapper;
import org.springframework.beans.factory.annotation.Autowired;
import java.util.Collection;
import org.openxma.dsl.platform.query.Expression;
import org.openxma.dsl.platform.query.QueryObject;
import org.openxma.dsl.reference.dao.AddressDao;
import org.openxma.dsl.reference.dao.CustomerDao;
import org.openxma.dsl.reference.dao.OrderDao;
import org.openxma.dsl.reference.dao.OrderItemDao;
import org.openxma.dsl.reference.dao.ProductDao;
import org.openxma.dsl.reference.dto.CustomerAddressDto;
import org.openxma.dsl.reference.dto.CustomerIdDto;
import org.openxma.dsl.reference.dto.CustomerView;
import org.openxma.dsl.reference.dto.OrderItemView;
import org.openxma.dsl.reference.dto.OrderView;
import org.openxma.dsl.reference.model.Address;
import org.openxma.dsl.reference.model.Customer;
import org.openxma.dsl.reference.model.Order;
import org.openxma.dsl.reference.model.OrderItem;
import org.openxma.dsl.reference.model.Product;
import org.openxma.dsl.reference.service.CustomerService;
import org.springframework.dao.OptimisticLockingFailureException;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.Assert;
public abstract class CustomerServiceGenImpl implements CustomerService {
	protected final Log logger = LogFactory.getLog(getClass());
	@Autowired(required=false)
	protected Mapper mapper;
	protected CustomerDao customerDao;
	protected AddressDao addressDao;
	protected OrderDao orderDao;
	protected OrderItemDao orderItemDao;
	protected ProductDao productDao;
	
	@Autowired
	public void setCustomerDao(CustomerDao customerDao) {
		this.customerDao = customerDao;
	}
	
	@Autowired
	public void setAddressDao(AddressDao addressDao) {
		this.addressDao = addressDao;
	}
	
	@Autowired
	public void setOrderDao(OrderDao orderDao) {
		this.orderDao = orderDao;
	}
	
	@Autowired
	public void setOrderItemDao(OrderItemDao orderItemDao) {
		this.orderItemDao = orderItemDao;
	}
	
	@Autowired
	public void setProductDao(ProductDao productDao) {
		this.productDao = productDao;
	}
	
	@Transactional
	public CustomerView save(CustomerView customerView) {
		Assert.notNull(customerView, "parameter 'customerView' must not be null");
		Customer customer = this.mapper.createAndMapOne(customerView, Customer.class,"saveCustomer");
		Address invoiceAddress = this.mapper.createAndMapOne(customerView, Address.class,"invoiceAddress");
		invoiceAddress = addressDao.load(invoiceAddress.getOid());
		customer.setInvoiceAddress(invoiceAddress);
		Address deliveryAddress = this.mapper.createAndMapOne(customerView, Address.class,"deliveryAddress");
		deliveryAddress = addressDao.load(deliveryAddress.getOid());
		customer.setDeliveryAddress(deliveryAddress);
		addOrders(customer,customerView);
		this.customerDao.saveOrUpdate(customer);
		return this.mapper.mapOne(customer,new CustomerView());
	}
	
	private void addOrders(Customer parentCustomer,CustomerView customerView) {
		if (customerView.getOrders() != null) {
			for (OrderView _orderView : customerView.getOrders()) {
				Order order = this.mapper.createAndMapOne(_orderView, Order.class,"saveOrder");
				addOrderItems(order,_orderView);
				parentCustomer.addOrders(order);
			}
		}
	}
	
	private void addOrderItems(Order parentOrder,OrderView orderView) {
		if (orderView.getOrderItems() != null) {
			for (OrderItemView _orderItemView : orderView.getOrderItems()) {
				OrderItem orderItem = this.mapper.createAndMapOne(_orderItemView, OrderItem.class,"saveOrderItem");
				Product product = this.mapper.createAndMapOne(_orderItemView, Product.class,"product");
				if (product.getOid() != null) {
					product = productDao.load(product.getOid());
					orderItem.setProduct(product);
				}
				parentOrder.addOrderItems(orderItem);
			}
		}
	}
	
	@Transactional(readOnly = true)
	public CustomerView loadCustomerView(String oid) {
		Assert.notNull(oid, "parameter 'oid' must not be null");
		return this.mapper.createAndMapOne(this.customerDao.load(oid),CustomerView.class);
	}
	
	@Transactional
	public void update(CustomerView customerView) {
		Assert.notNull(customerView, "parameter 'customerView' must not be null");
		Customer mappedCustomer = this.mapper.createAndMapOne(customerView, Customer.class);
		Customer customer = this.customerDao.load(mappedCustomer.getOid());
		if (!customer.getVersion().equals(mappedCustomer.getVersion())) {
			throw new OptimisticLockingFailureException("Entity 'Customer' was updated or deleted by another transaction.");
		}
		this.mapper.mapOne(customerView, customer,"updateCustomer");
	}
	
	@Transactional
	public void deleteCustomer(String oid) {
		Assert.notNull(oid, "parameter 'oid' must not be null");
		this.customerDao.delete(oid);
	}
	
	@Transactional
	public CustomerView saveOrUpdate(CustomerView customerView) {
		Assert.notNull(customerView, "parameter 'customerView' must not be null");
		if ( customerView.getVersion() == null ) {
			return this.save(customerView);
		}
		else {
			this.update(customerView);
			return customerView;
		}
	}
	
	
	@Transactional(readOnly=true)
	public Collection<CustomerView> findAllByFirstNameAndLastName(String firstName,String lastName) {
		return this.mapper.createAndMapMany(this.customerDao.findAllByFirstNameAndLastName(firstName,lastName),CustomerView.class);
	}
	
	@Transactional(readOnly=true)
	public Collection<CustomerView> findAllByFirstNameAndLastName(String firstName,String lastName,Expression _filter) {
		QueryObject queryObject = QueryObject.createNamedQuery(CustomerDao.FIND_ALL_BY_FIRST_NAME_AND_LAST_NAME0, _filter);
		queryObject.withArgs("firstName", firstName);
		queryObject.withArgs("lastName", lastName);
		Collection<Customer> _result =  this.customerDao.query(queryObject);
		return this.mapper.createAndMapMany(_result,CustomerView.class);
	}
	
	@Transactional(readOnly=true)
	public Collection<CustomerView> findAllByFirstNameAndLastName(String firstName,String lastName,String emailAddress) {
		return this.mapper.createAndMapMany(this.customerDao.findAllByFirstNameAndLastName(firstName,lastName,emailAddress),CustomerView.class);
	}
	
	@Transactional(readOnly=true)
	public Collection<CustomerView> findAllByFirstNameAndLastName(String firstName,String lastName,String emailAddress,Expression _filter) {
		QueryObject queryObject = QueryObject.createNamedQuery(CustomerDao.FIND_ALL_BY_FIRST_NAME_AND_LAST_NAME0, _filter);
		queryObject.withArgs("firstName", firstName);
		queryObject.withArgs("lastName", lastName);
		Collection<Customer> _result =  this.customerDao.query(queryObject);
		return this.mapper.createAndMapMany(_result,CustomerView.class);
	}
	
	@Transactional(readOnly=true)
	public Collection<CustomerAddressDto> testSubSelectBug() {
		return this.customerDao.testSubSelectBug();
	}
	
	@Transactional(readOnly=true)
	public Collection<CustomerAddressDto> testSubSelectBug(Expression _filter) {
		QueryObject queryObject = QueryObject.createNamedQuery(CustomerDao.TEST_SUB_SELECT_BUG, _filter);
		Collection<CustomerAddressDto> _result =  this.customerDao.query(queryObject);
		return _result;
	}
	
	@Transactional(readOnly=true)
	public Collection<CustomerAddressDto> testSubSelectBugInWhereClause() {
		return this.customerDao.testSubSelectBugInWhereClause();
	}
	
	@Transactional(readOnly=true)
	public Collection<CustomerAddressDto> testSubSelectBugInWhereClause(Expression _filter) {
		QueryObject queryObject = QueryObject.createNamedQuery(CustomerDao.TEST_SUB_SELECT_BUG_IN_WHERE_CLAUSE, _filter);
		Collection<CustomerAddressDto> _result =  this.customerDao.query(queryObject);
		return _result;
	}
	
	@Transactional(readOnly=true)
	public Collection<CustomerView> findByNamedQueryCustomerLastName(String lastName) {
		return this.mapper.createAndMapMany(this.customerDao.findByNamedQueryCustomerLastName(lastName),CustomerView.class);
	}
	
	@Transactional(readOnly=true)
	public Collection<CustomerIdDto> findAllCustomerIds() {
		return this.customerDao.findAllCustomerIds();
	}
	
	@Transactional(readOnly=true)
	public Collection<String> findAllCustomerIdLikeName(String name) {
		return this.customerDao.findAllCustomerIdLikeName(name);
	}
	
}
