package org.openxma.dsl.reference.service.impl;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.openxma.dsl.platform.service.Mapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.openxma.dsl.reference.dao.ProductDao;
import org.openxma.dsl.reference.dao.ProductImageDao;
import org.openxma.dsl.reference.dto.ProductImageView;
import org.openxma.dsl.reference.model.Product;
import org.openxma.dsl.reference.model.ProductImage;
import org.openxma.dsl.reference.service.ProductImageService;
import org.springframework.dao.OptimisticLockingFailureException;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.Assert;
public abstract class ProductImageServiceGenImpl implements ProductImageService {
	protected final Log logger = LogFactory.getLog(getClass());
	@Autowired(required=false)
	protected Mapper mapper;
	protected ProductImageDao productImageDao;
	protected ProductDao productDao;
	
	@Autowired
	public void setProductImageDao(ProductImageDao productImageDao) {
		this.productImageDao = productImageDao;
	}
	
	@Autowired
	public void setProductDao(ProductDao productDao) {
		this.productDao = productDao;
	}
	
	@Transactional
	public ProductImageView save(ProductImageView productImageView) {
		Assert.notNull(productImageView, "parameter 'productImageView' must not be null");
		ProductImage productImage = this.mapper.createAndMapOne(productImageView, ProductImage.class,"saveProductImage");
		Product product = this.mapper.createAndMapOne(productImageView, Product.class,"product");
		product = productDao.load(product.getOid());
		productImage.setProduct(product);
		this.productImageDao.saveOrUpdate(productImage);
		return this.mapper.mapOne(productImage,new ProductImageView());
	}
	
	@Transactional(readOnly = true)
	public ProductImageView loadProductImageView(String oid) {
		Assert.notNull(oid, "parameter 'oid' must not be null");
		return this.mapper.createAndMapOne(this.productImageDao.load(oid),ProductImageView.class);
	}
	
	@Transactional
	public void update(ProductImageView productImageView) {
		Assert.notNull(productImageView, "parameter 'productImageView' must not be null");
		ProductImage mappedProductImage = this.mapper.createAndMapOne(productImageView, ProductImage.class);
		ProductImage productImage = this.productImageDao.load(mappedProductImage.getOid());
		if (!productImage.getVersion().equals(mappedProductImage.getVersion())) {
			throw new OptimisticLockingFailureException("Entity 'ProductImage' was updated or deleted by another transaction.");
		}
		this.mapper.mapOne(productImageView, productImage,"updateProductImage");
	}
	
	@Transactional
	public void deleteProductImage(String oid) {
		Assert.notNull(oid, "parameter 'oid' must not be null");
		this.productImageDao.delete(oid);
	}
	
	@Transactional
	public ProductImageView saveOrUpdate(ProductImageView productImageView) {
		Assert.notNull(productImageView, "parameter 'productImageView' must not be null");
		if ( productImageView.getVersion() == null ) {
			return this.save(productImageView);
		}
		else {
			this.update(productImageView);
			return productImageView;
		}
	}
	
	
}
