package org.openxma.dsl.reference.ui.panels.server;

import at.spardat.xma.component.ComponentServer;
import at.spardat.xma.session.XMASessionServer;

/**
 * This class implements the generic server part of Panels.
 * It provides the mapping between typeIds and classnames
 * of all pages in the component.
 *
 */
abstract public class PanelsGen extends org.openxma.dsl.platform.xma.SpringComponentServer {


    /**
     * Initializes the PanelsGen. This method is called
     * by the XMA-Runtime.
     *
     * @param session the XMASession, this PanelsGen belongs to.
     * @param id the unique id of this Panels.
     */
    public PanelsGen (XMASessionServer session,short id) {
        super (session,false,id);
    }


    /** the unique typeId for the page PanelPage */
    public static final short PanelPageClass = 0;
    /** the unique typeId for the page VPanelPage */
    public static final short VPanelPageClass = 1;
    /** the unique typeId for the page HPanelPage */
    public static final short HPanelPageClass = 2;
    /** the unique typeId for the page ArrangedPanels */
    public static final short ArrangedPanelsClass = 3;

    /**
    * Array of the classnames of all pages in
    * this component. The typeIds are used as indices
    * into this array.
     */
    static final String[] modelClasses = {
        "PanelPage",
        "VPanelPage",
        "HPanelPage",
        "ArrangedPanels"
    };

    /**
    * Gets the short classname for the given typeId of
    * a page in this component. The short classname does
    * not contain the package.
    *
    * @param typeId the unique typeId
    * @return the short classname
     */
    static public String getShortModelClass(short typeId) {
        return modelClasses[typeId];
    }

    /**
    * Gets the full classname for the given typeId of
    * a page in this component.
    *
    * @param typeId the unique typeId
    * @return the full classname
     */
    public String getModelClass(short typeId) {
        return "org.openxma.dsl.reference.ui.panels.server."+modelClasses[typeId];
    }


}
