package org.openxma.dsl.reference.ui.styleselectors.client;

import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Shell;
import at.spardat.xma.component.EmbeddableComponent;
import at.spardat.xma.session.XMASessionClient;

/**
 * This class implements the generic client part of StyleSelectors.
 * It provides the mapping between typeIds and classnames
 * of all pages in the component.
 *
 */
abstract public class StyleSelectorsGen extends EmbeddableComponent implements IStyleSelectors {

    /**
     * Initializes the StyleSelectorsGen. This method is called
     * by the XMA-Runtime.
     *
     * @param session the XMASession, this StyleSelectorsGen belongs to.
     */
    public StyleSelectorsGen (XMASessionClient session) {
        super (session, false);
    }

    /** the unique typeId for the page TableColumnStylePage */
    public static final short TableColumnStylePageClass = 0;
    /** the unique typeId for the page StyleSelectorsPage */
    public static final short StyleSelectorsPageClass = 1;

    /**
    * Array of the classnames of all pages in
    * this component. The typeIds are used as indices
    * into this array.
     */
    static final String[] modelClasses = {
        "TableColumnStylePage",
        "StyleSelectorsPage"
    };

    /**
    * Gets the short classname for the given typeId of
    * a page in this component. The short classname does
    * not contain the package.
    *
    * @param typeId the unique typeId
    * @return the short classname
     */
    static public String getShortModelClass(short typeId) {
        return modelClasses[typeId];
    }

    /**
    * Gets the full classname for the given typeId of
    * a page in this component.
    *
    * @param typeId the unique typeId
    * @return the full classname
     */
    public String getModelClass(short typeId) {
        return "org.openxma.dsl.reference.ui.styleselectors.client."+modelClasses[typeId];
    }

    /**
     * Invokes the StyleSelectors. This method is a default
     * implementation, which invokes the first dialog page of the component.
     * Modeled init functions are called by this method.
     *
     * @param parentComposite a composite of the calling page. In most
     *     cases it will be a shell. It my be null.
     */
    public void invoke(Composite parentComposite) {
        TableColumnStylePage tableColumnStylePage_generatedXMAPage;
        if(parentComposite instanceof Shell) {
            tableColumnStylePage_generatedXMAPage = new TableColumnStylePage(this,(Shell)parentComposite);
        } else {
            tableColumnStylePage_generatedXMAPage = new TableColumnStylePage(this);
        }
        tableColumnStylePage_generatedXMAPage.invoke();
    }

    /**
     * Gives the URI of the help for this component
     * This URI is relative to the download-URI of the component
     * @return the relative URI of the help for this component
     */
    public String getHelpUri() {
        return "help/org/openxma/dsl/reference/ui/styleselectors/StyleSelectors.html";
    }

}
