package org.openxma.dsl.reference.ui.styleselectors.server;

import java.util.Locale;
import at.spardat.xma.page.*;
import at.spardat.xma.component.*;
import at.spardat.xma.mdl.*;
import at.spardat.enterprise.util.*;
import at.spardat.xma.mdl.simple.*;
import at.spardat.enterprise.fmt.*;
import at.spardat.xma.rpc.RemoteCall;
import at.spardat.xma.rpc.RemoteReply;

/**
 * This class implements the generic server part of StyleSelectorsPage.
 * It implements the models of the page.
 *
 */
public abstract class StyleSelectorsPageGen extends PageServer {
    ISimpleWM txt1;
    ISimpleWM txt2;
    ISimpleWM txt3a;
    ISimpleWM txt3b;
    ISimpleWM txt3c001;
    ISimpleWM txt3c002;
    ISimpleWM customer1_firstName;
    ISimpleWM customer1_lastName;
    ISimpleWM customer2_firstName;
    ISimpleWM customer2_lastName;
    WModel[] widgetModels;


    /**
     * Constructs the StyleSelectorsPageGen.
     * This constructor is called by the runtime. Do not remove!
     *
     * @param component the component this page belongs to
     */
    public StyleSelectorsPageGen(ComponentServer component) {
        super(component, false);
        createModels();
    }

    /**
     * Create and initialize the WidgetModels of the page.
     */
    public void createModels() {
        IFmt formatter;
        CompoundValidator compound;
        txt1 = new SimpleWM((short) 0, Types.T_STRING, this);
        formatter = AStringFmt.getInstance(-1);
        txt1.setFmt(formatter);
        txt2 = new SimpleWM((short) 1, Types.T_STRING, this);
        formatter = AStringFmt.getInstance(-1);
        txt2.setFmt(formatter);
        txt3a = new SimpleWM((short) 2, Types.T_STRING, this);
        formatter = AStringFmt.getInstance(-1);
        txt3a.setFmt(formatter);
        txt3b = new SimpleWM((short) 3, Types.T_STRING, this);
        formatter = AStringFmt.getInstance(-1);
        txt3b.setFmt(formatter);
        txt3c001 = new SimpleWM((short) 4, Types.T_STRING, this);
        formatter = AStringFmt.getInstance(-1);
        txt3c001.setFmt(formatter);
        txt3c002 = new SimpleWM((short) 5, Types.T_STRING, this);
        formatter = AStringFmt.getInstance(-1);
        txt3c002.setFmt(formatter);
        customer1_firstName = new SimpleWM((short) 6, Types.T_STRING, this);
        formatter = AStringFmt.getInstance(25);
        compound = new CompoundValidator(formatter);
        formatter = AStringFmt.getInstance(25);
        compound.setFormatter(formatter);
        formatter = compound;
        customer1_firstName.setFmt(formatter);
        customer1_firstName.setMandatory(true);
        customer1_lastName = new SimpleWM((short) 7, Types.T_STRING, this);
        formatter = AStringFmt.getInstance(50);
        compound = new CompoundValidator(formatter);
        formatter = AStringFmt.getInstance(50);
        compound.setFormatter(formatter);
        formatter = compound;
        customer1_lastName.setFmt(formatter);
        customer1_lastName.setMandatory(true);
        customer2_firstName = new SimpleWM((short) 8, Types.T_STRING, this);
        formatter = AStringFmt.getInstance(25);
        compound = new CompoundValidator(formatter);
        formatter = AStringFmt.getInstance(25);
        compound.setFormatter(formatter);
        formatter = compound;
        customer2_firstName.setFmt(formatter);
        customer2_firstName.setMandatory(true);
        customer2_lastName = new SimpleWM((short) 9, Types.T_STRING, this);
        formatter = AStringFmt.getInstance(50);
        compound = new CompoundValidator(formatter);
        formatter = AStringFmt.getInstance(50);
        compound.setFormatter(formatter);
        formatter = compound;
        customer2_lastName.setFmt(formatter);
        customer2_lastName.setMandatory(true);

        widgetModels = new WModel[] { (WModel) txt1, (WModel) txt2, (WModel) txt3a, (WModel) txt3b, (WModel) txt3c001, (WModel) txt3c002, (WModel) customer1_firstName, (WModel) customer1_lastName, (WModel) customer2_firstName, (WModel) customer2_lastName };
    }

    /*
     * returns the Locale used for this page
    */
    final protected Locale getGenPageLocale() {
        return getSession().getContext().getLocale();
    }

    /**
     * Returns an array of all WidgetModels of this page.
     * @return array of WidgetModels. The returned array is not a copy, therefore
     *          it must not be modified.
     */
    public WModel[] getWModels() {
        return widgetModels;
    }

    /**
     * Replaces the model array generated by guidesigner.
     * May only be called by the runtime. Do not call this method!
     */
    protected void setWModels(WModel[] models) {
        widgetModels=models;
    }

    /**
     * Returns a unique id to identify the type of this Page.
     * @return the typeId
     */
    public short getTypeId() {
        return StyleSelectors.StyleSelectorsPageClass;
    }

    /**
     * Returns the component this page belongs to, casted to its actual type.
     * @return The Component. Never null.
     */
    public StyleSelectors getTypedComponent() {
        return (StyleSelectors) getComponent();
    }

    /**
     * Copies values of all attached widget models to attributes of the BusinessData instance variables.
     * Copies them for this page and all contained NotebookPages and statically embedded Pages
     * (embedded via XMAContainer in guidesigner)
     */
    public void modelToInstanceData() {
        atomicWMToBusinessData(getTypedComponent().getCustomer1(), getTypedComponent().getCustomer2());
    }

    /**
     * Copies attribute values of the BusinessData instance variables into their attached widget models.
     * This includes simple widget models and tables.
     * Copies them for this page and all contained NotebookPages and statically embedded Pages
     * (embedded via XMAContainer in guidesigner)
     */
    public void instanceDataToModel() {
        businessDataToAtomicWM(getTypedComponent().getCustomer1(), getTypedComponent().getCustomer2());
    }

    /**
     * Copies values of widget models to attributes of the provided BusinessData objects.
     */
    public void atomicWMToBusinessData(org.openxma.dsl.reference.dto.CustomerView customer1, org.openxma.dsl.reference.dto.CustomerView customer2) {
        customer1.setFirstName(customer1_firstName.toString());
        customer1.setLastName(customer1_lastName.toString());
        customer2.setFirstName(customer2_firstName.toString());
        customer2.setLastName(customer2_lastName.toString());
    }

    /**
     * Copies attribute values of the provided BusinessDatas into widget models.
     */
    public void businessDataToAtomicWM(org.openxma.dsl.reference.dto.CustomerView customer1, org.openxma.dsl.reference.dto.CustomerView customer2) {
        customer1_firstName.set(customer1.getFirstName());
        customer1_lastName.set(customer1.getLastName());
        customer2_firstName.set(customer2.getFirstName());
        customer2_lastName.set(customer2.getLastName());
    }

    /**
     * Sets the given subpage. The method automatically chooses the
     * correct member variable to set.
     * @param child the subpage to set.
     */
    public void setChild(PageServer child) {
       // no subpages - nothing to do
    }

    /**
     * Removes the given subpage. The method automatically chooses the
     * correct member variable to clear.
     * @param child the subpage to set.
     */
    public void removeChild(PageServer child) {
       // no subpages - nothing to do
    }

    abstract public void load(RemoteCall call, RemoteReply reply);
}
