package org.openxma.dsl.reference.ui.styleselectors.server;

import java.util.Locale;
import at.spardat.xma.page.*;
import at.spardat.xma.component.*;
import at.spardat.xma.mdl.*;
import at.spardat.xma.mdl.table.*;
import at.spardat.enterprise.fmt.*;
import java.util.*;

/**
 * This class implements the generic server part of TableColumnStylePage.
 * It implements the models of the page.
 *
 */
public abstract class TableColumnStylePageGen extends PageServer {
    ITableWM customerTable;
    static final int CUSTOMERTABLE_FIRSTNAME = 0;
    static final int CUSTOMERTABLE_LASTNAME = 1;
    WModel[] widgetModels;


    /**
     * Constructs the TableColumnStylePageGen.
     * This constructor is called by the runtime. Do not remove!
     *
     * @param component the component this page belongs to
     */
    public TableColumnStylePageGen(ComponentServer component) {
        super(component, false);
        createModels();
    }

    /**
     * Create and initialize the WidgetModels of the page.
     */
    public void createModels() {
        IFmt formatter;
        customerTable = new TableWM((short) 0,this,2,TableWM.S_NULL|TableWM.S_ONE_WAY);

        widgetModels = new WModel[] { (WModel) customerTable };
    }

    /*
     * returns the Locale used for this page
    */
    final protected Locale getGenPageLocale() {
        return getSession().getContext().getLocale();
    }

    /**
     * Returns an array of all WidgetModels of this page.
     * @return array of WidgetModels. The returned array is not a copy, therefore
     *          it must not be modified.
     */
    public WModel[] getWModels() {
        return widgetModels;
    }

    /**
     * Replaces the model array generated by guidesigner.
     * May only be called by the runtime. Do not call this method!
     */
    protected void setWModels(WModel[] models) {
        widgetModels=models;
    }

    /**
     * Returns a unique id to identify the type of this Page.
     * @return the typeId
     */
    public short getTypeId() {
        return StyleSelectors.TableColumnStylePageClass;
    }

    /**
     * Returns the component this page belongs to, casted to its actual type.
     * @return The Component. Never null.
     */
    public StyleSelectors getTypedComponent() {
        return (StyleSelectors) getComponent();
    }

    /**
     * Copies values of all attached widget models to attributes of the BusinessData instance variables.
     * Copies them for this page and all contained NotebookPages and statically embedded Pages
     * (embedded via XMAContainer in guidesigner)
     */
    public void modelToInstanceData() {
    }

    /**
     * Copies attribute values of the BusinessData instance variables into their attached widget models.
     * This includes simple widget models and tables.
     * Copies them for this page and all contained NotebookPages and statically embedded Pages
     * (embedded via XMAContainer in guidesigner)
     */
    public void instanceDataToModel() {
        customerTableFill();
    }

    /**
     * This is a support method to create the table cells of one row from one or more BusinessDatas.
     * You may overwrite this method if you need a custom mapping from BusinessData attributes
     * to table columns that you were unable to specify in the UI designer.
     *
     * @return the returned Object[] is needed in the constructor of a <tt>TableRow</tt>.
     */
    public Object[] customerTableCreateCells(org.openxma.dsl.reference.dto.CustomerView customers) {
        Object []  cells = new Object[2];
        cells[0] = customers.getFirstName();
        cells[1] = customers.getLastName();
        return cells;
    }

    /**
     * This method creates a TableRow object and adds it to the end of the table.
     * The key of the row is drawn from the key attribute specified in the UI designer.
     * The image id is resolved by calling customerTableGetImageId. The cells of the table
     * are taken from a call to customerTableCreateCells.
     */
    public TableRow customerTableAddRow (org.openxma.dsl.reference.dto.CustomerView customers) {
        return new TableRow ((TableWM)customerTable, customers.getOid().toString(), customerTableCreateCells (customers), customerTableGetImageFor (customers));
    }

    /**
     * This method is called from <tt>customerTableAddRow</tt> to figure out an image
     * id for a particular row. If you do not overwrite this method, the table row
     * does not have an image id. 
     */
    public int customerTableGetImageFor (org.openxma.dsl.reference.dto.CustomerView customers) {
        return 0;
    }

    /**
     * This method iterates over the collection and calls <tt>customerTableAddRow</tt> for
     * each element.
     */
    public void customerTableFill () {
        customerTable.clear();
        for (Iterator iter = getTypedComponent().getCustomers().iterator(); iter.hasNext();) {
            customerTableAddRow ((org.openxma.dsl.reference.dto.CustomerView) iter.next());
        }
    }

    /**
     * Sets the given subpage. The method automatically chooses the
     * correct member variable to set.
     * @param child the subpage to set.
     */
    public void setChild(PageServer child) {
       // no subpages - nothing to do
    }

    /**
     * Removes the given subpage. The method automatically chooses the
     * correct member variable to clear.
     * @param child the subpage to set.
     */
    public void removeChild(PageServer child) {
       // no subpages - nothing to do
    }

}
