package org.openxma.dsl.reference.validation;

import org.openxma.dsl.reference.base.validation.BaseEntityValidator;
import org.openxma.dsl.reference.model.Customer;
import org.springframework.validation.Errors;
import org.springframework.validation.ValidationUtils;
import static org.openxma.dsl.platform.validation.ValidatorsHelper.*;


@SuppressWarnings("boxing")
public abstract class CustomerGenValidator extends BaseEntityValidator {
	
	@SuppressWarnings("unchecked")
	public boolean supports(Class clazz) {
		return Customer.class.isAssignableFrom(clazz);
	}
	
	public Errors validate(Customer customer) {
		Errors errors = createErrors(customer);
		super.validate(customer,errors);
		validate(customer,errors);
		return errors;
	}
	
	public void validate(Object object, Errors errors) {
		Customer customer = (Customer) object;
		ValidationUtils.rejectIfEmptyOrWhitespace(errors, "firstName", "field.required");
		ValidationUtils.rejectIfEmptyOrWhitespace(errors, "lastName", "field.required");
		ValidationUtils.rejectIfEmpty(errors, "gender", "field.required");
		ValidationUtils.rejectIfEmptyOrWhitespace(errors, "emailAddress", "field.required");
		ValidationUtils.rejectIfEmpty(errors, "birthDate", "field.required");
		ValidationUtils.rejectIfEmptyOrWhitespace(errors, "telefonNumber", "field.required");
		ValidationUtils.rejectIfEmpty(errors, "invoiceAddress", "field.required");
		ValidationUtils.rejectIfEmpty(errors, "deliveryAddress", "field.required");
		rejectIfMaxLength(errors,"firstName",customer.getFirstName(),25);
		rejectIfMaxLength(errors,"lastName",customer.getLastName(),50);
		rejectIfMaxLength(errors,"emailAddress",customer.getEmailAddress(),40);
		
	}
}
