package org.openxma.dsl.reference.validatortest;

import org.openxma.dsl.platform.service.MapperContextHolder;
import java.util.ArrayList;
import java.util.List;
import org.openxma.dsl.platform.assembler.DtoAssembler;
import org.openxma.dsl.platform.assembler.DtoAssemblerFactory;
import org.openxma.dsl.platform.assembler.DtoAssemblerRegistry;
import org.openxma.dsl.platform.converter.Converter;
import org.openxma.dsl.reference.validatortest.dto.SpringTestBaseEntityView;
import org.openxma.dsl.reference.validatortest.dto.SpringTestEntityView;
import org.openxma.dsl.reference.validatortest.model.SpringTestBaseEntity;
import org.openxma.dsl.reference.validatortest.model.SpringTestEntity;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.Assert;

public class DtoAssemblerFactoryValidatortestGen implements DtoAssemblerFactory {

	private List<DtoAssembler<?>> dtoAssemblers;

	@Autowired
	private DtoAssemblerRegistry dtoAssemblerRegistry;
	
	@Autowired
	private Converter converter;

	public DtoAssemblerFactoryValidatortestGen() {
		dtoAssemblers = new ArrayList<DtoAssembler<?>>(2);
		initDtoAssemblers();
	}


	public List<DtoAssembler<?>> getDtoAssemblers() {
		return dtoAssemblers;
	}

	protected DtoAssemblerRegistry getDtoAssemblerRegistry() {
		return dtoAssemblerRegistry;
	}
	
	protected Converter getConverter() {
		return converter;
	}

	private void initDtoAssemblers() {
		dtoAssemblers.add(createDtoAssemblerSpringTestBaseEntityView());
		dtoAssemblers.add(createDtoAssemblerSpringTestEntityView());
	}


	private DtoAssembler<SpringTestBaseEntityView> createDtoAssemblerSpringTestBaseEntityView() {
		return new DtoAssembler<SpringTestBaseEntityView>() {
			public SpringTestBaseEntityView mapFromEntity(Object sourceEntity) {
				Assert.notNull(sourceEntity, "parameter 'sourceEntity' must not be null");
				if (sourceEntity instanceof SpringTestBaseEntity) {
					SpringTestBaseEntity springTestBaseEntity = (SpringTestBaseEntity) sourceEntity;
					SpringTestBaseEntityView result = mapFromSpringTestBaseEntityToSpringTestBaseEntityView(springTestBaseEntity);
					return result;
				}
				throw new IllegalArgumentException("mapping from object '"+sourceEntity+"' is not supported");
					
			}
			
			public SpringTestBaseEntityView mapFromEntity(Object sourceEntity, SpringTestBaseEntityView targetDto) {
				Assert.notNull(sourceEntity, "parameter 'sourceEntity' must not be null");
				Assert.notNull(targetDto, "parameter 'targetDto' must not be null");
				if (sourceEntity instanceof SpringTestBaseEntity) {
					SpringTestBaseEntity springTestBaseEntity = (SpringTestBaseEntity) sourceEntity;
					mapFromSpringTestBaseEntityToSpringTestBaseEntityView(springTestBaseEntity, targetDto);
					return targetDto;
				}
				throw new IllegalArgumentException("mapping from object '"+sourceEntity+"' is not supported");
					
			}
			
			public <T> T mapTo(SpringTestBaseEntityView sourceDto, Class<T> target) {
				if (SpringTestBaseEntityView.class.equals(target)) {
					SpringTestBaseEntityView result = new SpringTestBaseEntityView();
					mapFromSpringTestBaseEntityViewToSpringTestBaseEntityView(sourceDto, result);
					return target.cast(result);
				}
				else if (SpringTestBaseEntity.class.equals(target)) {
					return target.cast(mapFromSpringTestBaseEntityViewToSpringTestBaseEntity(sourceDto));
				}
				else {
					throw new IllegalArgumentException("mapping to class '"+target+"' is not supported");
				}
			}
			
			public void mapTo(SpringTestBaseEntityView sourceDto, Object targetObject) {
				if (targetObject instanceof SpringTestBaseEntityView) {
					mapFromSpringTestBaseEntityViewToSpringTestBaseEntityView(sourceDto, (SpringTestBaseEntityView) targetObject);
				}
				else if (targetObject instanceof SpringTestBaseEntity) {
					mapFromSpringTestBaseEntityViewToSpringTestBaseEntity(sourceDto, (SpringTestBaseEntity)targetObject);
				}			   
				else if (targetObject != null) {
					throw new IllegalArgumentException("mapping to object '"+targetObject+"' is not supported");
				}
			}
		};
	}
	
	protected void mapFromSpringTestBaseEntityViewToSpringTestBaseEntityView(SpringTestBaseEntityView sourceDto, SpringTestBaseEntityView springTestBaseEntityView) {
		springTestBaseEntityView.setBaseString(sourceDto.getBaseString());
	}
	
	protected SpringTestBaseEntity mapFromSpringTestBaseEntityViewToSpringTestBaseEntity(SpringTestBaseEntityView sourceDto) {
		return mapFromSpringTestBaseEntityViewToSpringTestBaseEntity(sourceDto, MapperContextHolder.createEntity(SpringTestBaseEntity.class));
	}
	
	protected SpringTestBaseEntity mapFromSpringTestBaseEntityViewToSpringTestBaseEntity(SpringTestBaseEntityView sourceDto, SpringTestBaseEntity springTestBaseEntity) {
		if (MapperContextHolder.getContext().containsKey(sourceDto)) {
			return (SpringTestBaseEntity) MapperContextHolder.getContext().get(sourceDto);
		}
		MapperContextHolder.getContext().put(sourceDto, springTestBaseEntity);
		springTestBaseEntity.setBaseString(sourceDto.getBaseString());
		return springTestBaseEntity;
	}
	
	protected SpringTestBaseEntityView mapFromSpringTestBaseEntityToSpringTestBaseEntityView(SpringTestBaseEntity springTestBaseEntity) {
		if (MapperContextHolder.getContext().containsKey(springTestBaseEntity)) {
			return (SpringTestBaseEntityView) MapperContextHolder.getContext().get(springTestBaseEntity);
		}
		SpringTestBaseEntityView springTestBaseEntityView = new SpringTestBaseEntityView();
		MapperContextHolder.getContext().put(springTestBaseEntity, springTestBaseEntityView);
		springTestBaseEntityView.setBaseString(springTestBaseEntity.getBaseString());
		return springTestBaseEntityView;
	}
	
	protected SpringTestBaseEntityView mapFromSpringTestBaseEntityToSpringTestBaseEntityView(SpringTestBaseEntity springTestBaseEntity, SpringTestBaseEntityView springTestBaseEntityView) {
		if (MapperContextHolder.getContext().containsKey(springTestBaseEntity)) {
			return (SpringTestBaseEntityView) MapperContextHolder.getContext().get(springTestBaseEntity);
		}
		MapperContextHolder.getContext().put(springTestBaseEntity, springTestBaseEntityView);
		springTestBaseEntityView.setBaseString(springTestBaseEntity.getBaseString());
		return springTestBaseEntityView;
	}
	
	
	
	private DtoAssembler<SpringTestEntityView> createDtoAssemblerSpringTestEntityView() {
		return new DtoAssembler<SpringTestEntityView>() {
			public SpringTestEntityView mapFromEntity(Object sourceEntity) {
				Assert.notNull(sourceEntity, "parameter 'sourceEntity' must not be null");
				if (sourceEntity instanceof SpringTestEntity) {
					SpringTestEntity springTestEntity = (SpringTestEntity) sourceEntity;
					SpringTestEntityView result = mapFromSpringTestEntityToSpringTestEntityView(springTestEntity);
					return result;
				}
				throw new IllegalArgumentException("mapping from object '"+sourceEntity+"' is not supported");
					
			}
			
			public SpringTestEntityView mapFromEntity(Object sourceEntity, SpringTestEntityView targetDto) {
				Assert.notNull(sourceEntity, "parameter 'sourceEntity' must not be null");
				Assert.notNull(targetDto, "parameter 'targetDto' must not be null");
				if (sourceEntity instanceof SpringTestEntity) {
					SpringTestEntity springTestEntity = (SpringTestEntity) sourceEntity;
					mapFromSpringTestEntityToSpringTestEntityView(springTestEntity, targetDto);
					return targetDto;
				}
				throw new IllegalArgumentException("mapping from object '"+sourceEntity+"' is not supported");
					
			}
			
			public <T> T mapTo(SpringTestEntityView sourceDto, Class<T> target) {
				if (SpringTestEntityView.class.equals(target)) {
					SpringTestEntityView result = new SpringTestEntityView();
					mapFromSpringTestEntityViewToSpringTestEntityView(sourceDto, result);
					return target.cast(result);
				}
				else if (SpringTestEntity.class.equals(target)) {
					return target.cast(mapFromSpringTestEntityViewToSpringTestEntity(sourceDto));
				}
				else {
					throw new IllegalArgumentException("mapping to class '"+target+"' is not supported");
				}
			}
			
			public void mapTo(SpringTestEntityView sourceDto, Object targetObject) {
				if (targetObject instanceof SpringTestEntityView) {
					mapFromSpringTestEntityViewToSpringTestEntityView(sourceDto, (SpringTestEntityView) targetObject);
				}
				else if (targetObject instanceof SpringTestEntity) {
					mapFromSpringTestEntityViewToSpringTestEntity(sourceDto, (SpringTestEntity)targetObject);
				}			   
				else if (targetObject != null) {
					throw new IllegalArgumentException("mapping to object '"+targetObject+"' is not supported");
				}
			}
		};
	}
	
	protected void mapFromSpringTestEntityViewToSpringTestEntityView(SpringTestEntityView sourceDto, SpringTestEntityView springTestEntityView) {
		springTestEntityView.setBaseString(sourceDto.getBaseString());
		springTestEntityView.setStr(sourceDto.getStr());
		springTestEntityView.setCategory(sourceDto.getCategory());
	}
	
	protected SpringTestEntity mapFromSpringTestEntityViewToSpringTestEntity(SpringTestEntityView sourceDto) {
		return mapFromSpringTestEntityViewToSpringTestEntity(sourceDto, MapperContextHolder.createEntity(SpringTestEntity.class));
	}
	
	protected SpringTestEntity mapFromSpringTestEntityViewToSpringTestEntity(SpringTestEntityView sourceDto, SpringTestEntity springTestEntity) {
		if (MapperContextHolder.getContext().containsKey(sourceDto)) {
			return (SpringTestEntity) MapperContextHolder.getContext().get(sourceDto);
		}
		MapperContextHolder.getContext().put(sourceDto, springTestEntity);
		springTestEntity.setBaseString(sourceDto.getBaseString());
		springTestEntity.setStr(sourceDto.getStr());
		springTestEntity.setCategory(sourceDto.getCategory());
		return springTestEntity;
	}
	
	protected SpringTestEntityView mapFromSpringTestEntityToSpringTestEntityView(SpringTestEntity springTestEntity) {
		if (MapperContextHolder.getContext().containsKey(springTestEntity)) {
			return (SpringTestEntityView) MapperContextHolder.getContext().get(springTestEntity);
		}
		SpringTestEntityView springTestEntityView = new SpringTestEntityView();
		MapperContextHolder.getContext().put(springTestEntity, springTestEntityView);
		springTestEntityView.setBaseString(springTestEntity.getBaseString());
		springTestEntityView.setStr(springTestEntity.getStr());
		springTestEntityView.setCategory(springTestEntity.getCategory());
		return springTestEntityView;
	}
	
	protected SpringTestEntityView mapFromSpringTestEntityToSpringTestEntityView(SpringTestEntity springTestEntity, SpringTestEntityView springTestEntityView) {
		if (MapperContextHolder.getContext().containsKey(springTestEntity)) {
			return (SpringTestEntityView) MapperContextHolder.getContext().get(springTestEntity);
		}
		MapperContextHolder.getContext().put(springTestEntity, springTestEntityView);
		springTestEntityView.setBaseString(springTestEntity.getBaseString());
		springTestEntityView.setStr(springTestEntity.getStr());
		springTestEntityView.setCategory(springTestEntity.getCategory());
		return springTestEntityView;
	}
	
	
	
}
