package org.openxma.dsl.reference.xma.order.client;

import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Shell;
import at.spardat.xma.component.EmbeddableComponent;
import at.spardat.xma.session.XMASessionClient;

/**
 * This class implements the generic client part of Order.
 * It provides the mapping between typeIds and classnames
 * of all pages in the component.
 *
 */
abstract public class OrderGen extends EmbeddableComponent implements IOrder {

    /**
     * Initializes the OrderGen. This method is called
     * by the XMA-Runtime.
     *
     * @param session the XMASession, this OrderGen belongs to.
     */
    public OrderGen (XMASessionClient session) {
        super (session, false);
    }

    /** the unique typeId for the page OrderSearchForm */
    public static final short OrderSearchFormClass = 0;
    /** the unique typeId for the page OrderEditForm */
    public static final short OrderEditFormClass = 1;
    /** the unique typeId for the page Page1 */
    public static final short Page1Class = 2;
    /** the unique typeId for the page Page2 */
    public static final short Page2Class = 3;

    /**
    * Array of the classnames of all pages in
    * this component. The typeIds are used as indices
    * into this array.
     */
    static final String[] modelClasses = {
        "OrderSearchForm",
        "OrderEditForm",
        "Page1",
        "Page2"
    };

    /**
    * Gets the short classname for the given typeId of
    * a page in this component. The short classname does
    * not contain the package.
    *
    * @param typeId the unique typeId
    * @return the short classname
     */
    static public String getShortModelClass(short typeId) {
        return modelClasses[typeId];
    }

    /**
    * Gets the full classname for the given typeId of
    * a page in this component.
    *
    * @param typeId the unique typeId
    * @return the full classname
     */
    public String getModelClass(short typeId) {
        return "org.openxma.dsl.reference.xma.order.client."+modelClasses[typeId];
    }

    /**
     * Invokes the Order. This method is a default
     * implementation, which invokes the first dialog page of the component.
     * Modeled init functions are called by this method.
     *
     * @param parentComposite a composite of the calling page. In most
     *     cases it will be a shell. It my be null.
     */
    public void invoke(Composite parentComposite) {
        OrderSearchForm orderSearchForm;
        if(parentComposite instanceof Shell) {
            orderSearchForm = new OrderSearchForm(this,(Shell)parentComposite);
        } else {
            orderSearchForm = new OrderSearchForm(this);
        }
        orderSearchForm.invoke();
    }

    /**
     * Gives the URI of the help for this component
     * This URI is relative to the download-URI of the component
     * @return the relative URI of the help for this component
     */
    public String getHelpUri() {
        return "help/org/openxma/dsl/reference/xma/order/Order.html";
    }

}
