package org.openxma.dsl.reference.xma.order.server;

import java.util.Locale;
import at.spardat.xma.page.*;
import at.spardat.xma.component.*;
import at.spardat.xma.mdl.*;
import at.spardat.enterprise.util.*;
import at.spardat.xma.mdl.simple.*;
import at.spardat.enterprise.fmt.*;

/**
 * This class implements the generic server part of Page1.
 * It implements the models of the page.
 *
 */
public abstract class Page1Gen extends PageServer {
    ISimpleWM customer_firstName;
    ISimpleWM customer_lastName;
    ISimpleWM orderState_orderNumber;
    ISimpleWM orderState_storeId;
    ISimpleWM orderState_placementDate;
    ISimpleWM orderState_deliveryDate;
    ISimpleWM orderState_orderState;
    WModel[] widgetModels;


    /**
     * Constructs the Page1Gen.
     * This constructor is called by the runtime. Do not remove!
     *
     * @param component the component this page belongs to
     */
    public Page1Gen(ComponentServer component) {
        super(component, false);
        createModels();
    }

    /**
     * Create and initialize the WidgetModels of the page.
     */
    public void createModels() {
        IFmt formatter;
        CompoundValidator compound;
        customer_firstName = new SimpleWM((short) 0, Types.T_STRING, this);
        formatter = AStringFmt.getInstance(25);
        compound = new CompoundValidator(formatter);
        formatter = AStringFmt.getInstance(25);
        compound.setFormatter(formatter);
        formatter = compound;
        customer_firstName.setFmt(formatter);
        customer_firstName.setMandatory(true);
        customer_lastName = new SimpleWM((short) 1, Types.T_STRING, this);
        formatter = AStringFmt.getInstance(50);
        compound = new CompoundValidator(formatter);
        formatter = AStringFmt.getInstance(50);
        compound.setFormatter(formatter);
        formatter = compound;
        customer_lastName.setFmt(formatter);
        customer_lastName.setMandatory(true);
        orderState_orderNumber = new SimpleWM((short) 2, Types.T_STRING, this);
        formatter = AStringFmt.getInstance(-1);
        compound = new CompoundValidator(formatter);
        formatter = AStringFmt.getInstance(-1);
        compound.setFormatter(formatter);
        formatter = compound;
        orderState_orderNumber.setFmt(formatter);
        orderState_orderNumber.setMandatory(true);
        orderState_storeId = new SimpleWM((short) 3, Types.T_STRING, this);
        formatter = AStringFmt.getInstance(-1);
        compound = new CompoundValidator(formatter);
        formatter = AStringFmt.getInstance(-1);
        compound.setFormatter(formatter);
        formatter = compound;
        orderState_storeId.setFmt(formatter);
        orderState_storeId.setMandatory(true);
        orderState_placementDate = new SimpleWM((short) 4, Types.T_DATE, this);
        formatter = ADateFmt.getInstance(ADateFmt.MEDIUM, getGenPageLocale());
        compound = new CompoundValidator(formatter);
        formatter = ADateFmt.getInstance(ADateFmt.MEDIUM, getGenPageLocale());
        compound.setFormatter(formatter);
        formatter = compound;
        orderState_placementDate.setFmt(formatter);
        orderState_placementDate.setMandatory(true);
        orderState_deliveryDate = new SimpleWM((short) 5, Types.T_DATE, this);
        formatter = ADateFmt.getInstance(ADateFmt.MEDIUM, getGenPageLocale());
        compound = new CompoundValidator(formatter);
        formatter = ADateFmt.getInstance(ADateFmt.MEDIUM, getGenPageLocale());
        compound.setFormatter(formatter);
        formatter = compound;
        orderState_deliveryDate.setFmt(formatter);
        orderState_deliveryDate.setMandatory(false);
        orderState_orderState = new SimpleWM((short) 6, Types.T_STRING, this);
        formatter = AStringFmt.getInstance(33);
        compound = new CompoundValidator(formatter);
        formatter = AStringFmt.getInstance(33);
        compound.setFormatter(formatter);
        formatter = compound;
        orderState_orderState.setFmt(formatter);
        orderState_orderState.setMandatory(true);

        widgetModels = new WModel[] { (WModel) customer_firstName, (WModel) customer_lastName, (WModel) orderState_orderNumber, (WModel) orderState_storeId, (WModel) orderState_placementDate, (WModel) orderState_deliveryDate, (WModel) orderState_orderState };
    }

    /*
     * returns the Locale used for this page
    */
    final protected Locale getGenPageLocale() {
        return getSession().getContext().getLocale();
    }

    /**
     * Returns an array of all WidgetModels of this page.
     * @return array of WidgetModels. The returned array is not a copy, therefore
     *          it must not be modified.
     */
    public WModel[] getWModels() {
        return widgetModels;
    }

    /**
     * Replaces the model array generated by guidesigner.
     * May only be called by the runtime. Do not call this method!
     */
    protected void setWModels(WModel[] models) {
        widgetModels=models;
    }

    /**
     * Returns a unique id to identify the type of this Page.
     * @return the typeId
     */
    public short getTypeId() {
        return Order.Page1Class;
    }

    /**
     * Returns the component this page belongs to, casted to its actual type.
     * @return The Component. Never null.
     */
    public Order getTypedComponent() {
        return (Order) getComponent();
    }

    /**
     * Copies values of all attached widget models to attributes of the BusinessData instance variables.
     * Copies them for this page and all contained NotebookPages and statically embedded Pages
     * (embedded via XMAContainer in guidesigner)
     */
    public void modelToInstanceData() {
        atomicWMToBusinessData(getTypedComponent().getOrderState(), getTypedComponent().getCustomer());
    }

    /**
     * Copies attribute values of the BusinessData instance variables into their attached widget models.
     * This includes simple widget models and tables.
     * Copies them for this page and all contained NotebookPages and statically embedded Pages
     * (embedded via XMAContainer in guidesigner)
     */
    public void instanceDataToModel() {
        businessDataToAtomicWM(getTypedComponent().getOrderState(), getTypedComponent().getCustomer());
    }

    /**
     * Copies values of widget models to attributes of the provided BusinessData objects.
     */
    public void atomicWMToBusinessData(org.openxma.dsl.reference.dto.OrderStateView orderState, org.openxma.dsl.reference.dto.CustomerView customer) {
        customer.setFirstName(customer_firstName.toString());
        customer.setLastName(customer_lastName.toString());
        orderState.setOrderNumber(org.openxma.dsl.reference.types.valueobject.OrderNumber.newOrNull(orderState_orderNumber.toString()));
        orderState.setStoreId(orderState_storeId.toString());
        orderState.setPlacementDate(orderState_placementDate.toDate());
        orderState.setDeliveryDate(orderState_deliveryDate.toDate());
        orderState.setOrderState(orderState_orderState.toString());
    }

    /**
     * Copies attribute values of the provided BusinessDatas into widget models.
     */
    public void businessDataToAtomicWM(org.openxma.dsl.reference.dto.OrderStateView orderState, org.openxma.dsl.reference.dto.CustomerView customer) {
        customer_firstName.set(customer.getFirstName());
        customer_lastName.set(customer.getLastName());
          orderState_orderNumber.set(org.openxma.dsl.platform.valueobject.ValueObject.valueOrNull(orderState.getOrderNumber()));
        orderState_storeId.set(orderState.getStoreId());
        orderState_placementDate.set(orderState.getPlacementDate());
        orderState_deliveryDate.set(orderState.getDeliveryDate());
        orderState_orderState.set(orderState.getOrderState());
    }

    /**
     * Sets the given subpage. The method automatically chooses the
     * correct member variable to set.
     * @param child the subpage to set.
     */
    public void setChild(PageServer child) {
       // no subpages - nothing to do
    }

    /**
     * Removes the given subpage. The method automatically chooses the
     * correct member variable to clear.
     * @param child the subpage to set.
     */
    public void removeChild(PageServer child) {
       // no subpages - nothing to do
    }

}
